# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "expss", "sandwich", "lmtest", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(expss) #for labels
library(sandwich) #for clustered SE
library(lmtest) #for coeftest
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter3_exercise3")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter3_exercise3")

txtStart("responsiveness_R.txt")

# Function for linear hypothesis w/ clustered SE
# taken from https://stackoverflow.com/questions/40120094/how-to-conduct-linear-hypothesis-test-on-regression-coefficients-with-a-clustere
# Modified to allow for difference in coefficients test
LinearCombTest <- function (lmObject, vars, .vcov = NULL, sum = 1) {
  ## if `.vcov` missing, use the one returned by `lm`
  if (is.null(.vcov)) .vcov <- vcov(lmObject)
  ## estimated coefficients
  beta <- coef(lmObject)
  ## sum of `vars`
  if(sum == 1){
    sumvars <- sum(beta[vars])
  }
  if(sum == 2){
    sumvars <- beta[vars[1]] - beta[vars[2]]
  }
  
  ## get standard errors for sum of `vars`
  se <- sum(.vcov[vars, vars]) ^ 0.5
  ## perform t-test on `sumvars`
  tscore <- sumvars / se
  pvalue <- 2 * pt(abs(tscore), lmObject$df.residual, lower.tail = FALSE)
  ## return a matrix
  matrix(c(sumvars, se, tscore, pvalue), nrow = 1L,
         dimnames = list(paste0(paste0(vars, collapse = " + "), " = 0"),
                         c("Estimate", "Std. Error", "t value", "Pr(>|t|)")))
}

# Load in data
data <- read_dta('AJPS2006.dta')

#---- Below is the replication code from Adams et al. 2006 to create the final version of their dataset. ----

data <- data %>%
  group_by(ctrynum, electnum) %>%
  mutate(clnum = cur_group_id())
  
#---- Generate variables -- not all of these are used in the final models ----
data <- data %>%
  mutate(
    pshift2 = (partyshift2 * (9/200)),
    pshiftt12 = (partyshiftprev * (9/200)),
    pshiftt22 = (partyshiftminustwo * (9/200)),
    pshift2a = abs(pshift2),
    vshift = vshiftidparty + vshiftmsparty,
    idvshift = idparty * vshift,
    idpshift = idparty * pshift2a,
    msparty = ifelse(idparty == 0, 1, 0),
    msvshift = msparty * vshift,
    dir = if_else(leftwingparty == 1, 1, 0),
    dir = if_else(rightwingparty == 1, -1, dir),
    centpart = ifelse(dir == 0, 1, 0),
    cconverge = centpart * diffANCPun,
    dirpshift = dir * pshift2,
    moderate = ifelse(dirpshift > 0, 1, 0),
    modid = moderate * idparty,
    pshiftmod = moderate * pshift2a,
    idpshiftmod = moderate * pshift2a * idparty,
    iddpshift = idparty * dirpshift,
    dir2 = ifelse(leftwingparty == 1, -1, 0),
    dir2 = ifelse(rightwingparty == 1, 1, dir2),
    dirvshift = dir2 * vshift
  ) %>%
  arrange(clnum) %>%
  group_by(clnum) %>%
  mutate(
    lvotec = log(votecurrent),
    lvotec1 = log(voteminusone),
    lvotec2 = log(voteminustwo),
    votec = votecurrent - voteminusone,
    votec1 = voteminusone - voteminustwo,
    converge = sum(pshiftmod)) %>%
  ungroup() %>%
  mutate(
    idconverge = idparty * converge,
    lvgain = lvotec - lvotec1,
    lvgainone = lvotec1 - lvotec2,
    cgovunemp = ingovnow * changeunemp3,
    cgovgdp = ingovnow * changegdp3,
    federal = ifelse(fedundim > 0, 1, 0),
    logmag = log(magnitude),
    #these just pick up Communists in Spain
    idfederal = idparty * federal,
    idlogmag = idparty * logmag
  ) %>%
  group_by(clnum) %>%
  mutate(numgov = cumsum(ingovnow)) %>%
  ungroup() %>%
  mutate(
    coalgov = ifelse(numgov > 1, 1, 0),
    ccogovun = changeunemp3 * coalgov,
    ccogovgdp = changegdp3 * coalgov,
    Gunemp = Green * changeunemp3,
    pshiftAN = unweighted_AN * pshift2a,
    vshiftAN = unweighted_AN * vshift,
    dirid = dir * idparty,
    pvoteshift = votec1 * pshiftt12,
    opinion_niche=vshift*idparty
  )

#----	Replication for Question 3 in Chapter 3 begins) ----			        
data <- apply_labels(data, 
             pshift2 = "change in party position",
             vshift = "Public opinion shift",
             idparty = "Niche party",
             opinion_niche = "Public opinion shift X niche party",
             pshiftt12 = "Previous policy shift",
             votec1 = "Previous change in vote share",
             pvoteshift = "Previous policy shift X previous change in vote share"
             )
data <- rename(data, 
               party_shift = pshift2,
               opinion_shift = vshift,
               niche_party = idparty)


#---- Produce results from the standard interaction model shown in Table S.2 in the Solutions chapter ----
mod1 <- lm(party_shift ~ niche_party + opinion_niche + opinion_shift + pshiftt12 +
      votec1 + pvoteshift + Italy + Britain + Greece + Luxembourg + Denmark +
      Netherlands + Spain, data)
vcov_mod1 <- vcovCL(mod1, type = "HC1", cluster = ~clnum)
mod1CL <- coeftest(mod1, vcov_mod1); mod1CL

#---- Calculate the marginal effect of Public Opinion Shift when the party is a niche party. ----
LinearCombTest(mod1, c("opinion_shift", "opinion_niche"), vcov_mod1)
# Lower bound
LinearCombTest(mod1, c("opinion_shift", "opinion_niche"), vcov_mod1)[1] -
  qt(0.975, mod1$df.residual)*LinearCombTest(mod1, c("opinion_shift", "opinion_niche"), vcov_mod1)[2]
# Upper bound
LinearCombTest(mod1, c("opinion_shift", "opinion_niche"), vcov_mod1)[1] +
  qt(0.975, mod1$df.residual)*LinearCombTest(mod1, c("opinion_shift", "opinion_niche"), vcov_mod1)[2]
#---- Produce results from the alternative interaction model shown in Table 3.4 and later in Table S.2 in the Solutions chapter. ----
data <- mutate(data, opinion_mainstream=opinion_shift*(1-niche_party))
mod2 <- lm(party_shift ~ niche_party + opinion_mainstream + opinion_niche + pshiftt12 + votec1 +
             pvoteshift + Italy + Britain + Greece + Luxembourg + Denmark + Netherlands + Spain, data) 
vcov_mod2 <- vcovCL(mod2, type = "HC1", cluster = ~clnum)
mod2CL <- coeftest(mod2, vcov_mod2); mod2CL
mod2$df.residual

#---- Is the effect of Public Opinion Shift different for mainstream ----
	# 	parties as opposed to niche parties? This is captured by the 	
	# 	interaction term in the standard interaction model. However, we	
	#   can also calculate it from the alternative interaction model.
LinearCombTest(mod2, c("opinion_niche", "opinion_mainstream"), vcov_mod2, sum = 2)
# Lower bound
LinearCombTest(mod2, c("opinion_niche", "opinion_mainstream"), vcov_mod2, sum = 2)[1] -
  qt(0.975, mod2$df.residual)*LinearCombTest(mod2, c("opinion_niche", "opinion_mainstream"), vcov_mod2, sum = 2)[2]
# Upper bound
LinearCombTest(mod2, c("opinion_niche", "opinion_mainstream"), vcov_mod2, sum = 2)[1] +
  qt(0.975, mod2$df.residual)*LinearCombTest(mod2, c("opinion_niche", "opinion_mainstream"), vcov_mod2, sum = 2)[2]
txtStop()