# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation and ggplot
library(psych) #to describe data
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter5_application1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter5_application1")

txtStart("anes2016_analysis_R.txt")

#---- Load in data ----
data <- read_dta('anes2016_small.dta')

#---- Variable description ----
names(data)

#---- Drop respondents who are not white or black ----
data <- filter(data, white == 1 | black == 1)

#---- Generate interaction term for gender and race ----
data <- data %>%
  mutate(
    female_black = female*black,
    female_white = female*white,
    male_black = male*black,
    male_white = male*white
  )

data <- data %>%
  dplyr::select(respondent_id, female, male, black, white, female_black, female_white, male_black, male_white, everything()) 

#---- summary statistics ----
describe(data)
describe(data$like_republican)
describe(data$female)

#---- Produce results shown in Table 5.1 in Chapter 5	----

# Standard interaction model
mod1 <- lm(like_republican ~ female + black + female_black + age, data)
summary(mod1)

# Alternative interaction model I
mod2 <- lm(like_republican ~ female_white + male_black + female_black + age, data)
summary(mod2)

# Alternative interaction model II
mod3 <- lm(like_republican  ~ female_white +  male_black +  male_white + age, data)
summary(mod3)

#---- Let's look at effects based on the standard interaction model ----

# Variance-covariance matrix of the estimated coefficients
vcov(mod1)

#---- Obtain degrees of freedom ----
df <- summary(mod1)$df[2]; df

#---- Obtain critical t-value for this degrees of freedom assuming an alpha level of 0.05	----
qt(0.025, df, lower.tail = FALSE)

#---- Effect of being female among Whites ----
mod1_FemWhite <- glht(mod1, linfct = c("female = 0")); summary(mod1_FemWhite)
confint(mod1_FemWhite)
women_whites <- as.numeric(summary(mod1_FemWhite)$test[[3]]); women_whites

#---- Effect of being female among Blacks ----
mod1_FemBlack <- glht(mod1, linfct = c("female + female_black = 0")); summary(mod1_FemBlack)
confint(mod1_FemBlack)
women_blacks <-as.numeric(summary(mod1_FemBlack)$test[[3]]); women_blacks

#---- Effect of being Black among men ----
mod1_MaleBlack <- glht(mod1, linfct = c("black = 0")); summary(mod1_MaleBlack)
confint(mod1_MaleBlack)
blacks_men <- as.numeric(summary(mod1_MaleBlack)$test[[3]]); blacks_men

#---- Effect of being Black among women ----
mod1_BlackFem <- glht(mod1, linfct = c("black + female_black = 0")); summary(mod1_BlackFem)
confint(mod1_BlackFem)
blacks_women <- as.numeric(summary(mod1_BlackFem)$test[[3]]); blacks_women

#---- Interaction effect
summary(glht(mod1, linfct = c("female_black = 0")))
confint(summary(glht(mod1, linfct = c("female_black = 0"))))

# The values reported by the preceding glht commands can be used to create Figure 5.1.	We show this below.

#---- Substantive size of interaction effect ---- 
women_blacks/women_whites
blacks_women/blacks_men

#---- Predicted values based on the standard interaction model. These predictions provide some of the values in Figure 5.2. ----

# 40 year old White male	
summary(glht(mod1, linfct = c("(Intercept) + 40 * age = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + 40 * age = 0"))))
predict(mod1, newdata = data.frame(female = 0, black = 0, female_black = 0, age = 40), se.fit=TRUE, interval="confidence")

# 40 year old White female
summary(glht(mod1, linfct = c("(Intercept) + female + 40 * age = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + female + 40 * age = 0"))))
predict(mod1, newdata = data.frame(female = 1, black = 0, female_black = 0, age = 40), se.fit=TRUE, interval="confidence")

# 40 year old Black male
summary(glht(mod1, linfct = c("(Intercept) + black + 40 * age = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + black + 40 * age = 0"))))
predict(mod1, newdata = data.frame(female = 0, black = 1, female_black = 0, age = 40), se.fit=TRUE, interval="confidence")

# 40 year old Black female
summary(glht(mod1, linfct = c("(Intercept) + female + black + female_black + 40 * age = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + female + black + female_black + 40 * age = 0"))))
predict(mod1, newdata = data.frame(female = 1, black = 1, female_black = 1, age = 40), se.fit=TRUE, interval="confidence")

#---- Differences in predicted values are the same as effects. These differences provide the other values in Figure 5.2. ----

# Effect of female among Whites or difference between White women White men		
summary(glht(mod1, linfct = c("female = 0")))
confint(summary(glht(mod1, linfct = c("female = 0"))))

# Effect of female among Blacks or difference between Black women	and Black men	
summary(glht(mod1, linfct = c("female + female_black = 0")))
confint(summary(glht(mod1, linfct = c("female + female_black = 0"))))

# Effect of being Black among men	or difference between Black men	and White men	
summary(glht(mod1, linfct = c("black = 0")))
confint(summary(glht(mod1, linfct = c("black = 0"))))

# Effect of being Black among women or difference between Black	women and White women
summary(glht(mod1, linfct = c("black + female_black = 0")))
confint(summary(glht(mod1, linfct = c("black + female_black = 0"))))

# Interaction effect

# Difference between (i) the difference between Black women and White women and 
# (ii) the difference between Black men and White men
summary(glht(mod1, linfct = c("female_black = 0")))
confint(summary(glht(mod1, linfct = c("female_black = 0"))))

# Difference between (i) the difference between Black women and Black men and 
# (ii) the difference between White women and White men
summary(glht(mod1, linfct = c("female_black = 0")))
confint(summary(glht(mod1, linfct = c("female_black = 0"))))

# Interaction term coefficient
summary(glht(mod1, linfct = c("female_black = 0")))
confint(summary(glht(mod1, linfct = c("female_black = 0"))))

#---- Effects based on the alternative interaction model I ----
summary(mod2)
vcov(mod2)

#---- Interaction effect ----
summary(glht(mod2, linfct = c("female_black - female_white - male_black = 0")))
confint(summary(glht(mod2, linfct = c("female_black - female_white - male_black = 0"))))

#---- Effect of being female among Whites ----
summary(glht(mod2, linfct = c("female_white = 0")))
confint(summary(glht(mod2, linfct = c("female_white = 0"))))

#---- Effect of being female among Blacks ----
summary(glht(mod2, linfct = c("female_black - male_black = 0")))
confint(summary(glht(mod2, linfct = c("female_black - male_black = 0"))))

#---- Effect of being Black among men ----
summary(glht(mod2, linfct = c("male_black = 0")))
confint(summary(glht(mod2, linfct = c("male_black = 0"))))

#---- Effect of being Black among women ----
summary(glht(mod2, linfct = c("female_black - female_white = 0")))
confint(summary(glht(mod2, linfct = c("female_black - female_white = 0"))))

#---- Predicted values based on the alternative interaction model I ----

#---- 40 year old White male ----
summary(glht(mod2, linfct = c("(Intercept) + 40 * age = 0")))
confint(summary(glht(mod2, linfct = c("(Intercept) + 40 * age = 0"))))

# 40 year old White female
summary(glht(mod2, linfct = c("(Intercept) + female_white + 40 * age = 0")))
confint(summary(glht(mod2, linfct = c("(Intercept) + female_white + 40 * age = 0"))))

# 40 year old Black male
summary(glht(mod2, linfct = c("(Intercept) + male_black + 40 * age = 0")))
confint(summary(glht(mod2, linfct = c("(Intercept) + male_black + 40 * age = 0"))))

# 40 year old Black female
summary(glht(mod2, linfct = c("(Intercept) + female_black + 40 * age = 0")))
confint(summary(glht(mod2, linfct = c("(Intercept) + female_black + 40 * age = 0"))))

#---- The analysis is robust to including additional controls ----
mod4 <- lm(like_republican ~ female_white + male_black + female_black + age +
             highschool + undergrad + grad + income, data)
summary(mod4)

#---- Produce a figure like Figure 5.1 in R Note that the figures in the book were created using pgfplots, not R ----
summary(mod1)

#---- Create a 5 x 4 matrix to store inputs for creating plot	----
plot <- as.data.frame(matrix(NA, 5, 4))
colnames(plot) <- c("estimate", "lb","ub", "num")

#---- Obtain the point estimates and standard errors for the effects shown in Figure 5.1 and place them in the matrix ----

plot[1, 1] <- summary(mod1)$coefficients[4, 1]
plot[1, 2] <- confint(mod1)[4, 1]
plot[1, 3] <- confint(mod1)[4, 2]

plot[2, 1] <- as.numeric(summary(mod1_FemWhite)$test[[3]])
plot[2, 2] <- as.numeric(confint(mod1_FemWhite)$confint[[2]])
plot[2, 3] <- as.numeric(confint(mod1_FemWhite)$confint[[3]])

plot[3, 1] <- as.numeric(summary(mod1_FemBlack)$test[[3]])
plot[3, 2] <- as.numeric(confint(mod1_FemBlack)$confint[[2]])
plot[3, 3] <- as.numeric(confint(mod1_FemBlack)$confint[[3]])

plot[4, 1] <- as.numeric(summary(mod1_MaleBlack)$test[[3]])
plot[4, 2] <- as.numeric(confint(mod1_MaleBlack)$confint[[2]])
plot[4, 3] <- as.numeric(confint(mod1_MaleBlack)$confint[[3]])

plot[5, 1] <- as.numeric(summary(mod1_BlackFem)$test[[3]])
plot[5, 2] <- as.numeric(confint(mod1_BlackFem)$confint[[2]])
plot[5, 3] <- as.numeric(confint(mod1_BlackFem)$confint[[3]])

plot$num <- c(5:1)

#---- Produce the plot using ggplot ----
ggplot(plot) + 
  geom_pointrange(aes(x = num, y = estimate, ymin = lb, ymax = ub), position = position_dodge(width = 0.5), lwd = 0.4, fatten = 5, stroke = 0.4) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  ylim(-3, 0.5) +
  labs(y = "Effect Size", x = "", shape = "", title = "") +
  theme_bw()  +
  annotate("text", y  = -1.03, x = 5.2, label = "-1.03") +  
  annotate("text", y  = -0.04, x = 4.2, label = "-0.04") +  
  annotate("text", y  = -1.07, x = 3.2, label = "-1.07") +  
  annotate("text", y  = -1.50, x = 2.2, label = "-1.50") +  
  annotate("text", y  = -2.53, x = 1.2, label = "-2.53") +  
  coord_flip() + 
  scale_x_discrete(limits = c("Effect of being Black among women", 
                              "Effect of being Black among men",
                              "Effect of being Female Among Blacks", 
                              "Effect of being Female among Whites",
                              "Interaction Effect for Gender and Race"))
txtStop()
