# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation and ggplot
library(psych) #to describe data
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
setwd("~/Dropbox/ali/replications/chapter5_application2")
#setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter5_application2")

txtStart("anes2012_analysis_R.txt")

#---- Load in data ----
data <- read_dta('anes2012_small.dta')

#---- Variable description ----
names(data)
describe(data)

#---- Drop respondents who are not white or black ----
data <- filter(data, white == 1 | black == 1)

#---- Generate variable for ideological distance ----
data$ideological_distance = abs(data$left_right - data$left_right_obama)

#---- Generate interaction term for race and ideological distance ----
data$ideological_distance_black = data$ideological_distance * data$black

#---- Some summary statistics ----
describe(data$thermometer_obama)
describe(data$ideological_distance)
describe(data$black)

#---- dependent variable among Whites ----
dv_whites <- data %>%
  filter(black == 0) %>%
  dplyr::select(thermometer_obama)
describe(dv_whites$thermometer_obama)

#---- dependent variable among Blacks ----
dv_blacks <- data %>%
  filter(black == 1) %>%
  dplyr::select(thermometer_obama)
describe(dv_blacks$thermometer_obama)

#---- dependent variable among Whites who are congruent with Obama ----
dv_whites_Obama <- data %>%
  filter(black == 0 & ideological_distance == 0) %>%
  dplyr::select(thermometer_obama)
describe(dv_whites_Obama$thermometer_obama)

#---- ideological incongruence among Whites ----
ideo_whites <- data %>%
  filter(black == 0) %>%
  dplyr::select(ideological_distance)
describe(ideo_whites$ideological_distance)

#---- ideological incongruence among Blacks ----
ideo_blacks <- data %>%
  filter(black == 1) %>%
  dplyr::select(ideological_distance)
describe(ideo_blacks$ideological_distance)

#---- Produce results shown in Table 5.3 in Chapter 5	----

#---- Standard interaction model ----
mod1 <- lm(thermometer_obama ~ ideological_distance + black + ideological_distance_black, data)
summary(mod1)

#---- Alternative interaction model ----
data$ideological_distance_white = data$ideological_distance * (1 - data$black)
mod2 <-  lm(thermometer_obama ~ black + ideological_distance_white  + ideological_distance_black,data)
summary(mod2)

#---- Split Sample ----
data_whites <- data %>%
  filter(black == 0)
mod3 <- lm(thermometer_obama ~ ideological_distance, data_whites); summary(mod3)

data_blacks<- data %>%
  filter(black == 1)
mod4 <- lm(thermometer_obama ~ ideological_distance, data_blacks); summary(mod4)

#---- Some effects based on the standard interaction model ----
summary(mod1)

#---- Variance-covariance matrix of the estimated coefficients ----
vcov(mod1)

#---- Obtain degrees of freedom ----
df <- summary(mod1)$df[2]; df

#---- Obtain critical t-value for this degrees of freedom assuming an alpha level of 0.05	----
qt(0.025, df, lower.tail = FALSE)

#---- Effect of ideological incongruence among Whites ----
ideologyW <- summary(glht(mod1, linfct = c("ideological_distance = 0")))
confint(ideologyW)
ideology_whites <- as.numeric(summary(ideologyW)$test[[3]]); ideology_whites

#---- Effect of ideological incongruence among Blacks ----
ideologyB <- summary(glht(mod1, linfct = c("ideological_distance + ideological_distance_black = 0")))
confint(ideologyB)
ideology_blacks <- as.numeric(summary(ideologyB)$test[[3]]); ideology_blacks

#---- Interaction effect ----
summary(glht(mod1, linfct = c("ideological_distance_black = 0")))
confint(summary(glht(mod1, linfct = c("ideological_distance_black = 0"))))

#---- Substantive size of interaction effect ----
ideology_whites/ideology_blacks

#---- Effect of being Black at different values of ideological incongruence. -----	
# This provides one column of the information in  Table 5.4. 
# It also provides the point estimates and confidence intervals for Figure 5.4	

summary(glht(mod1, linfct = c("black = 0")))
confint(summary(glht(mod1, linfct = c("black = 0"))))

summary(glht(mod1, linfct = c("black + ideological_distance_black*1 = 0")))
confint(summary(glht(mod1, linfct = c("black + ideological_distance_black*1 = 0"))))

summary(glht(mod1, linfct = c("black + ideological_distance_black*2 = 0")))
confint(summary(glht(mod1, linfct = c("black + ideological_distance_black*2 = 0"))))

summary(glht(mod1, linfct = c("black + ideological_distance_black*3 = 0")))
confint(summary(glht(mod1, linfct = c("black + ideological_distance_black*3 = 0"))))

summary(glht(mod1, linfct = c("black + ideological_distance_black*4 = 0")))
confint(summary(glht(mod1, linfct = c("black + ideological_distance_black*4 = 0"))))

summary(glht(mod1, linfct = c("black + ideological_distance_black*5 = 0")))
confint(summary(glht(mod1, linfct = c("black + ideological_distance_black*5 = 0"))))

summary(glht(mod1, linfct = c("black + ideological_distance_black*6 = 0")))
confint(summary(glht(mod1, linfct = c("black + ideological_distance_black*6 = 0"))))

#---- Produce a figure like Figure 5.3 in R ----
# Note that the figures in the book were created using pgfplots, not R
summary(mod1)

#---- Create a 3 x 4 matrix to store inputs for creating plot	----
plot <- as.data.frame(matrix(NA, 3, 4))
colnames(plot) <- c("estimate", "lb","ub", "num")

#---- Obtain the point estimates and standard errors for the effects shown in Figure 5.1 and place them in the matrix	----
plot[1, 1] <- summary(mod1)$coefficients[4, 1]
plot[1, 2] <- confint(mod1)[4, 1]
plot[1, 3] <- confint(mod1)[4, 2]

plot[2, 1] <- summary(mod1)$coefficients[2, 1]
plot[2, 2] <- confint(mod1)[2, 1]
plot[2, 3] <- confint(mod1)[2, 2]

mod1_ideoBlack <- glht(mod1, linfct = c("ideological_distance + ideological_distance_black*1 = 0"))
plot[3, 1] <- as.numeric(summary(mod1_ideoBlack)$test[[3]])
plot[3, 2] <- as.numeric(confint(mod1_ideoBlack)$confint[[2]])
plot[3, 3] <- as.numeric(confint(mod1_ideoBlack)$confint[[3]])

plot$num <- c(3:1)

#---- Produce the plot using ggplot ----
ggplot(plot) + 
  geom_pointrange(aes(x = num, y = estimate, ymin = lb, ymax = ub), position = position_dodge(width = 0.5), lwd = 0.4, fatten = 5, stroke = 0.4) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  ylim(-15, 15) +
  labs(y = "Effect Size", x = "", shape = "", title = "") +
  theme_bw()  +
  annotate("text", y  = 10.17, x = 3.2, label = "10.17") +  
  annotate("text", y  = -3.39, x = 1.2, label = "-3.39") +  
  annotate("text", y  = -13.55, x = 2.2, label = "-13.55") +  
  coord_flip() + 
  scale_x_discrete(limits = c("Effect of Ideological Incongruence among Blacks", 
                              "Effect of Ideological Incongruence among Whites",
                              "Interaction Effect for Ideological Incongruence and Race"))

#---- Obtain remaining information to complete Table 5.4. ----
# Note that	we only want data for those respondents in our estimation sample. 
# We can also use this data to produce histograms in Figures 5.4, 5.5, 5.6b
esample<-rownames(as.matrix(resid(mod1)))
data_esample <- data[esample, ]

table(data_esample$black)
table(data_esample$black[data_esample$ideological_distance == 0])
table(data_esample$black[data_esample$ideological_distance == 1])
table(data_esample$black[data_esample$ideological_distance == 2])
table(data_esample$black[data_esample$ideological_distance == 3])
table(data_esample$black[data_esample$ideological_distance == 4])
table(data_esample$black[data_esample$ideological_distance == 5])
table(data_esample$black[data_esample$ideological_distance == 6])
describe(data_esample$thermometer_obama[data_esample$black == 0 & data_esample$ideological_distance == 0])
describe(data_esample$thermometer_obama[data_esample$black == 0 & data_esample$ideological_distance == 1])
describe(data_esample$thermometer_obama[data_esample$black == 0 & data_esample$ideological_distance == 2])
describe(data_esample$thermometer_obama[data_esample$black == 0 & data_esample$ideological_distance == 3])
describe(data_esample$thermometer_obama[data_esample$black == 0 & data_esample$ideological_distance == 4])
describe(data_esample$thermometer_obama[data_esample$black == 0 & data_esample$ideological_distance == 5])
describe(data_esample$thermometer_obama[data_esample$black == 0 & data_esample$ideological_distance == 6])

#---- Produce a figure like Figure 5.4 in R ----
# Note that the figures in the book were created using pgfplots, not R
summary(mod1)

#---- Create a 7 x 4 matrix to store inputs for creating plot	----
plot <- as.data.frame(matrix(NA, 7, 4))
colnames(plot) <- c("estimate", "lb","ub", "num")

#---- Obtain the point estimates and standard errors for the effects shown in Figure 5.1 and place them in the matrix	----

mod1_blackIdeo0 <- glht(mod1, linfct = c("black = 0"))
plot[1, 1] <- as.numeric(summary(mod1_blackIdeo0)$test[[3]])
plot[1, 2] <- as.numeric(confint(mod1_blackIdeo0)$confint[[2]])
plot[1, 3] <- as.numeric(confint(mod1_blackIdeo0)$confint[[3]])

mod1_blackIdeo1 <- glht(mod1, linfct = c("black + ideological_distance_black*1 = 0"))
plot[2, 1] <- as.numeric(summary(mod1_blackIdeo1)$test[[3]])
plot[2, 2] <- as.numeric(confint(mod1_blackIdeo1)$confint[[2]])
plot[2, 3] <- as.numeric(confint(mod1_blackIdeo1)$confint[[3]])

mod1_blackIdeo2 <- glht(mod1, linfct = c("black + ideological_distance_black*2 = 0"))
plot[3, 1] <- as.numeric(summary(mod1_blackIdeo2)$test[[3]])
plot[3, 2] <- as.numeric(confint(mod1_blackIdeo2)$confint[[2]])
plot[3, 3] <- as.numeric(confint(mod1_blackIdeo2)$confint[[3]])

mod1_blackIdeo3 <- glht(mod1, linfct = c("black + ideological_distance_black*3 = 0"))
plot[4, 1] <- as.numeric(summary(mod1_blackIdeo3)$test[[3]])
plot[4, 2] <- as.numeric(confint(mod1_blackIdeo3)$confint[[2]])
plot[4, 3] <- as.numeric(confint(mod1_blackIdeo3)$confint[[3]])

mod1_blackIdeo4 <- glht(mod1, linfct = c("black + ideological_distance_black*4 = 0"))
plot[5, 1] <- as.numeric(summary(mod1_blackIdeo4)$test[[3]])
plot[5, 2] <- as.numeric(confint(mod1_blackIdeo4)$confint[[2]])
plot[5, 3] <- as.numeric(confint(mod1_blackIdeo4)$confint[[3]])

mod1_blackIdeo5 <- glht(mod1, linfct = c("black + ideological_distance_black*5 = 0"))
plot[6, 1] <- as.numeric(summary(mod1_blackIdeo5)$test[[3]])
plot[6, 2] <- as.numeric(confint(mod1_blackIdeo5)$confint[[2]])
plot[6, 3] <- as.numeric(confint(mod1_blackIdeo5)$confint[[3]])

mod1_blackIdeo6 <- glht(mod1, linfct = c("black + ideological_distance_black*6 = 0"))
plot[7, 1] <- as.numeric(summary(mod1_blackIdeo6)$test[[3]])
plot[7, 2] <- as.numeric(confint(mod1_blackIdeo6)$confint[[2]])
plot[7, 3] <- as.numeric(confint(mod1_blackIdeo6)$confint[[3]])

plot$num <- c(1:7)

#---- Produce the plot using ggplot ----
ggplot(plot) + 
  geom_pointrange(aes(x = num, y = estimate, ymin = lb, ymax = ub), position = position_dodge(width = 0.5), lwd = 0.4, fatten = 5, stroke = 0.4) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  ylim(0, 90) +
  labs(y = "Effect of being Black instead of White", x = "Ideological Incongruence between Respondent and Obama", shape = "", title = "") +
  theme_bw()  +
  scale_x_discrete(limits = c("0","1","2","3", "4", "5", "6")) +
  annotate("text", y  = 12.51, x = 0.7, label = "12.51") +  
  annotate("text", y  = 22.68, x = 1.7, label = "22.68") +  
  annotate("text", y  = 32.84, x = 2.7, label = "32.84") +  
  annotate("text", y  = 43.01, x = 3.7, label = "43.01") +  
  annotate("text", y  = 53.18, x = 4.7, label = "53.18") +  
  annotate("text", y  = 63.34, x = 5.7, label = "63.34") +  
  annotate("text", y  = 73.51, x = 6.7, label = "73.51")   

#---- Produce a figure like Figure 5.5 in R ----
# Note that the figures in the book were created using pgfplots, not R
summary(mod1)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals ----
b1 <- mod1$coefficients[2]; b1
b2 <- mod1$coefficients[3]; b2
b3 <- mod1$coefficients[4]; b3
varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
covb1b3 <- vcov(mod1)[2, 4]; covb1b3
covb3b2 <- vcov(mod1)[4, 3]; covb3b2

vcov(mod1)

n <- 1:620
MV <- (n-1)/100
conbx <- b2+b3*MV
consx <- sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2)
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)
MV <- MV[1:601]
conbx <- conbx[1:601]
cons <- consx[1:601]
lowerx <- lowerx[1:601]
upperx <- upperx[1:601]

#---- Produce the plot like Figure 5.5. ----
# The plot is not identical to the one in Figure 5.5 because the histogram doesn't
# distinguish between Blacks and Whites. It is possible to add histograms by Blacks
# and Whites but the two histograms each sum to 100 percent when we want them together
# to sum to 100	percent. There's probably an easy way to get this, but we	didn't use R.	

ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data_esample$ideological_distance, y = (..count..)/sum(..count..)*100*4), alpha = 0.1) +
  scale_x_discrete(limits = c("1", "2", "3", "4", "5", "6")) +
  theme_bw() + 
  ylim(0,100) +
  scale_y_continuous(
  name = "Effect of being Black instead of White",
  sec.axis = sec_axis(~./4, name="Percentage of Observations")
  ) +
  xlab("Ideological Incongruence between Respondent and Obama") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")

#---- At what value of Ideological Incongruence is the confidence	interval at its narrowest?	----
covb3b2/varb3

#---- We can also check this numerically to 2 decimal places.	----
gap <- upperx-lowerx
describe(gap)
min_gap = describe(gap)$min; min_gap
MV[gap==min_gap]

#---- Mean of Ideological Incongruence in the estimation sample is NOT the same. ----
describe(data_esample$ideological_distance)

#---- Some more stuff with the alternative interaction model ----
summary(mod2)

#---- Interaction effect ----
summary(glht(mod2, linfct = c("ideological_distance_black - ideological_distance_white = 0")))
confint(summary(glht(mod2, linfct = c("ideological_distance_black - ideological_distance_white = 0"))))

summary(glht(mod2, linfct = c("black = 0")))
confint(summary(glht(mod2, linfct = c("black = 0"))))

summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*1 = 0")))
confint(summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*1 = 0"))))

summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*2 = 0")))
confint(summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*2 = 0"))))

summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*3 = 0")))
confint(summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*3 = 0"))))

summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*4 = 0")))
confint(summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*4 = 0"))))

summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*5 = 0")))
confint(summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*5 = 0"))))

summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*6 = 0")))
confint(summary(glht(mod2, linfct = c("black + (ideological_distance_black - ideological_distance_white)*6 = 0"))))

#---- Let's add some control variables to get results for Table 5.5 ----

#---- Standard interaction model -----
mod5 <- lm(thermometer_obama ~ ideological_distance + black + ideological_distance_black +
             democrat + republican + age + female + income + highschool + undergrad + grad, data)
summary(mod5)

#---- Alternative interaction model ----
mod6 <-  lm(thermometer_obama ~ black + ideological_distance_white  + ideological_distance_black +
              democrat + republican + age + female + income + highschool + undergrad + grad,data)
summary(mod6)

#---- Split Sample ----
mod7 <- lm(thermometer_obama ~ ideological_distance +
             democrat + republican + age + female + income + highschool + undergrad + grad, data_whites); summary(mod7)

mod8 <- lm(thermometer_obama ~ ideological_distance +
             democrat + republican + age + female + income + highschool + undergrad + grad, data_blacks); summary(mod8)

#---- Produce a figure like Figure 5.7a in R ----
# Note that the figures in the book were created using pgfplots, not R
summary(mod5)

#---- Create a 3 x 4 matrix to store inputs for creating plot	----
plot <- as.data.frame(matrix(NA, 3, 4))
colnames(plot) <- c("estimate", "lb","ub", "num")

#---- Obtain the point estimates and standard errors for the effects shown in Figure 5.1 and place them in the matrix	----
plot[1, 1] <- summary(mod5)$coefficients[4, 1]
plot[1, 2] <- confint(mod5)[4, 1]
plot[1, 3] <- confint(mod5)[4, 2]

plot[2, 1] <- summary(mod5)$coefficients[2, 1]
plot[2, 2] <- confint(mod5)[2, 1]
plot[2, 3] <- confint(mod5)[2, 2]

mod5_ideoBlack <- glht(mod5, linfct = c("ideological_distance + ideological_distance_black*1 = 0"))
plot[3, 1] <- as.numeric(summary(mod5_ideoBlack)$test[[3]])
plot[3, 2] <- as.numeric(confint(mod5_ideoBlack)$confint[[2]])
plot[3, 3] <- as.numeric(confint(mod5_ideoBlack)$confint[[3]])

plot$num <- c(3:1)

#---- Produce the plot using ggplot ----
ggplot(plot) + 
  geom_pointrange(aes(x = num, y = estimate, ymin = lb, ymax = ub), position = position_dodge(width = 0.5), lwd = 0.4, fatten = 5, stroke = 0.4) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  ylim(-12, 12) +
  labs(y = "Effect Size", x = "", shape = "", title = "") +
  theme_bw()  +
  annotate("text", y  = 8.01, x = 3.2, label = "8.01") +  
  annotate("text", y  = -1.95, x = 1.2, label = "-1.95") +  
  annotate("text", y  = -9.96, x = 2.2, label = "-9.96") +  
  coord_flip() + 
  scale_x_discrete(limits = c("Effect of Ideological Incongruence among Blacks", 
                              "Effect of Ideological Incongruence among Whites",
                              "Interaction Effect for Ideological Incongruence and Race"))

#---- Produce a figure like Figure 5.7b in R ----
# Note that the figures in the book were created using pgfplots, not R
summary(mod5)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals ----
b1 <- mod5$coefficients[2]; b1
b2 <- mod5$coefficients[3]; b2
b3 <- mod5$coefficients[4]; b3
varb1 <- vcov(mod5)[2, 2]; varb1
varb2 <- vcov(mod5)[3, 3]; varb2
varb3 <- vcov(mod5)[4, 4]; varb3
covb1b3 <- vcov(mod5)[2, 4]; covb1b3
covb3b2 <- vcov(mod5)[4, 3]; covb3b2

vcov(mod5)

n <- 1:620
MV <- (n-1)/100
conbx <- b2+b3*MV
consx <- sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2)
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)
MV <- MV[1:601]
conbx <- conbx[1:601]
cons <- consx[1:601]
lowerx <- lowerx[1:601]
upperx <- upperx[1:601]

#---- Produce the plot like Figure 5.7b. ----
# The plot is not identical to the one in Figure 5.7b because the histogram doesn't
# distinguish between Blacks and Whites.

ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data_esample$ideological_distance, y = (..count..)/sum(..count..)*100*4), alpha = 0.1) +
  scale_x_discrete(limits = c("1", "2", "3", "4", "5", "6")) +
  theme_bw() + 
  ylim(0,100) +
  scale_y_continuous(
    name = "Effect of being Black instead of White",
    sec.axis = sec_axis(~./4, name="Percentage of Observations")
  ) +
  xlab("Ideological Incongruence between Respondent and Obama") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")

txtStop()
