# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "regclass", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation and ggplot
library(psych) #to describe data
library(multcomp) #for glht
library(regclass) #for VIF
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter5_application3")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter5_application3")

txtStart("analysis_R.txt")
#---- Load in data ----
data <- read_dta('final.dta')

#---- Variable description ----
names(data)

#---- Some summary statistics	----
describe(data)

describe(data$womens_representation[data$year > 1989])

describe(data$women_leaders)

min_leader <- describe(data$women_leaders)$min; min_leader
data %>%
  filter(women_leaders == min_leader) %>%
  dplyr::select(women_leaders, countryname, year)

max_leader <- describe(data$women_leaders)$max; max_leader
data %>%
  filter(women_leaders == max_leader) %>%
  dplyr::select(women_leaders, countryname, year)

describe(data$labor)

min_labor <- describe(data$labor)$min; min_labor
data %>%
  filter(labor == min_labor) %>%
  dplyr::select(labor, countryname, year)

max_labor = describe(data$labor)$max; max_labor
data %>%
  filter(labor == max_labor) %>%
  dplyr::select(labor, countryname, year)

#---- Generate interaction term ----
data$leaders_labor = data$women_leaders * data$labor

#---- Produce results shown in Table 5.6 in Chapter 5		----

#---- Standard interaction model - uncentered ----
mod1 <- lm(womens_representation ~ women_leaders + labor + leaders_labor + effectivequota + polity, data)
summary(mod1)

VIF(mod1)
mean(c(VIF(mod1)[1], VIF(mod1)[2], VIF(mod1)[3], VIF(mod1)[4], VIF(mod1)[5]))
1/(c(VIF(mod1)[1], VIF(mod1)[2], VIF(mod1)[3], VIF(mod1)[4], VIF(mod1)[5]))

#---- Standard interaction model - centered ----
data <- data %>%
  mutate(centered_women_leaders = women_leaders - mean(women_leaders, na.rm = T),
         centered_labor = labor - mean(labor, na.rm = T), 
         centered_demand_supply = centered_women_leaders * centered_labor)

mod2 <- lm(womens_representation ~ centered_women_leaders + centered_labor + 
             centered_demand_supply + effectivequota + polity, data)
summary(mod2)

VIF(mod2)
mean(c(VIF(mod2)[1], VIF(mod2)[2], VIF(mod2)[3], VIF(mod2)[4], VIF(mod2)[5]))
1/(c(VIF(mod2)[1], VIF(mod2)[2], VIF(mod2)[3], VIF(mod2)[4], VIF(mod2)[5]))

#---- Some effects based on the uncentered standard interaction model ----
summary(mod1)

vcov(mod1)

describe(data$labor)
supply_min <- describe(data$labor)$min; supply_min
supply_max <- describe(data$labor)$max; supply_max
supply_mean <- describe(data$labor)$mean; supply_mean

describe(data$women_leaders)
demand_min <- describe(data$women_leaders)$min; demand_min
demand_max <- describe(data$women_leaders)$max; demand_max
demand_mean <- describe(data$women_leaders)$mean; demand_mean

#---- Effect of demand when supply is at its minimum observed value ----
summary(glht(mod1, linfct = c("women_leaders + leaders_labor * 8.61398 = 0")))
confint(summary(glht(mod1, linfct = c("women_leaders + leaders_labor * 8.61398 = 0"))))

#---- Effect of demand when supply is at its maximum observed value ----
summary(glht(mod1, linfct = c("women_leaders + leaders_labor * 111.0102 = 0")))
confint(summary(glht(mod1, linfct = c("women_leaders + leaders_labor * 111.0102 = 0"))))

#---- Effect of supply when demand is at its minimum observed value ---- 
summary(glht(mod1, linfct = c("labor + leaders_labor * 7.977675 = 0")))
confint(summary(glht(mod1, linfct = c("labor + leaders_labor * 7.977675 = 0"))))

#---- Effect of supply when demand is at its maximum observed value ---- 
summary(glht(mod1, linfct = c("labor + leaders_labor * 91.81818 = 0")))
confint(summary(glht(mod1, linfct = c("labor + leaders_labor * 91.81818 = 0"))))

#---- Produce a figure like Figure 5.8a in R showing the marginal	effect of demand across the observed range of values for supply. ----
# Note that the figures in the book were created using pgfplots not R 
summary(mod1)
describe(data$labor)
describe(data$women_leaders)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals ----
b1 <- mod1$coefficients[2]; b1
b2 <- mod1$coefficients[3]; b2
b3 <- mod1$coefficients[4]; b3
varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
covb1b3 <- vcov(mod1)[2, 4]; covb1b3
covb3b2 <- vcov(mod1)[4, 3]; covb3b2

vcov(mod1)

n <- 1:11167
MV <- (n-1)/100
conbx <- b1+b3*MV
consx <- sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3) 

#---- Obtain degrees of freedom and critical t-value for creating	confidence intervals ----
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)

#---- Limit to range of observed data. ----
MV <- MV[864:11103]
conbx <- conbx[864:11103]
lowerx <- lowerx[864:11103]
upperx <- upperx[864:11103]

#---- Draw the plot. ----
# The histogram differs slightly from the one shown in Figure 5.8a because the 
# bar widths and locations are not identical.
ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  xlim(0, 115) +
  geom_histogram(aes(x = data$labor, y = (..count..)/sum(..count..)*100/10), bins = 55, alpha = 0.1) +
  theme_bw() + 
  ylim(-1,1) +
  scale_y_continuous(
    name = "Marginal Effect of Demand",
    sec.axis = sec_axis(~.*10, name="Percentage of Observations")
  ) +
  xlab("Supply (Ratio of Female to Male Labor Force Participation)") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Information about percentage of observations in different regions based on marginal effect plot. ----

#---- When is the effect of demand negative and statistically insignificant? ----
-mod1$coefficients[2] / mod1$coefficients[4]

describe(data$labor)
total <- describe(data$labor)$n; total

describe(data$labor[data$labor<36.94])
subtotal1 <- describe(data$labor[data$labor<36.94])$n; subtotal1

(subtotal1/total)*100

#---- When is the effect of demand positive and statistically	insignificant? ----
# You can use the method shown in Online Appendix	
# D to calculate the relevant cutpoint or you can look at the 
# values in the data editor that we calculated when producing the
# plot in Figure 5.8a. We use the values in the data editor. The 
# range is between 36.94 and 50.88.	

describe(data$labor[data$labor>36.94 & data$labor<50.88])
subtotal2 <- describe(data$labor[data$labor>36.94 & data$labor<50.88])$n; subtotal2

(subtotal2/total)*100

#---- When is the effect of demand positive and statistically significant?	
# You can use the method shown in Online Appendix
# D to calculate the relevant cutpoint or you can look at the 
# values in the data editor that we calculated when producing the
# plot in Figure 5.8a. We use the values in the data editor. It 
# occurs when supply is larger than 50.88

describe(data$labor[data$labor>50.88])
subtotal3 <- describe(data$labor[data$labor>50.88])$n; subtotal3

(subtotal3/total)*100

#---- What about substantive significance of effect of demand? ----
# 20 unit increase in demand when supply is at mean and max values.	
describe(data$womens_representation[data$year==2018])
rep2018 <- describe(data$womens_representation[data$year==2018])$mean

describe(data$women_leaders)
demand_sd <- describe(data$women_leaders)$sd; demand_sd

supply_mean
supply_max

summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 67.87846)*20 = 0")))
effect_mean <- as.numeric(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 67.87846)*20 = 0")))$test[3])
(effect_mean/rep2018)*100

summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 111.0102)*20 = 0")))
effect_max <- as.numeric(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 111.0102)*20 = 0")))$test[3])

(effect_max/rep2018)*100

#---- Modifying effect of supply ----
(effect_max/effect_mean)*100

((effect_max-effect_mean)/rep2018)*100

#---- Effect of one unit increase in demand when supply is at mean and max values. ----
summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 67.87846)= 0")))
confint(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 67.87846) = 0"))))

summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 111.0102) = 0")))
confint(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor * 111.0102) = 0"))))

#---- Produce a figure like Figure 5.8b in R showing the marginal	effect of supply across the observed range of values for demand. ----
# Note that the figures in the book were created using pgfplots not R
rm(MV, conbx, consx, lowerx, upperx)
summary(mod1)
describe(data$labor)
describe(data$women_leaders)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals ----
b1 <- mod1$coefficients[2]; b1
b2 <- mod1$coefficients[3]; b2
b3 <- mod1$coefficients[4]; b3
varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
covb1b3 <- vcov(mod1)[2, 4]; covb1b3
covb3b2 <- vcov(mod1)[4, 3]; covb3b2

vcov(mod1)

n <- 1:9399
MV <- (n-1)/100
conbx <- b2+b3*MV
consx <- sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2)

#---- Obtain degrees of freedom and critical t-value for creating	confidence intervals ----
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)

#---- Limit to range of observed data. ----
MV <- MV[799:9184]
conbx <- conbx[799:9184]
lowerx <- lowerx[799:9184]
upperx <- upperx[799:9184]

#---- Draw the plot. ----
# The histogram differs slightly from the one shown in Figure 5.8b because the bar
# widths and locations are not identical.	
ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  xlim(0, 115) +
  geom_histogram(aes(x = data$women_leaders, y = (..count..)/sum(..count..)*100/10), bins = 21, alpha = 0.1) +
  theme_bw() + 
  ylim(-1,1) +
  scale_y_continuous(
    name = "Marginal Effect of Supply",
    sec.axis = sec_axis(~.*10, name="Percentage of Observations")
  ) +
  xlab("Demand") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")


#---- Information about percentage of observations in different	regions based on marginal effect plot. ----

#---- When is the effect of supply negative and statistically insignificant? ----
# You can use the method shown in Online Appendix	
# D to calculate the relevant cutpoint or you can look at the 	
# values in the data editor that we calculated when producing the	
# plot in Figure 5.8b. We use the values in the data editor. It 
# occurs when demand is less than 16.36.

describe(data$women_leaders)
total2 <- describe(data$women_leaders)$n; total2

describe(data$women_leaders[data$women_leaders<16.36])
subtotal2 <- describe(data$women_leaders[data$women_leaders<16.36])$n; subtotal2

(subtotal2/total2)*100

#---- When is the effect of supply positive and statistically insignificant?	----
# You can use the method shown in Online Appendix	
# D to calculate the relevant cutpoint or you can look at the 
# values in the data editor that we calculated when producing the
# plot in Figure 5.8b. We use the values in the data editor. The 
# range is between 16.36 and 26.52. 

describe(data$women_leaders[data$women_leaders>16.36 & data$women_leaders < 26.52])
subtotal3 <- describe(data$women_leaders[data$women_leaders>16.36 & data$women_leaders < 26.52])$n; subtotal3

(subtotal3/total2)*100

#---- When is the effect of supply positive and statistically significant? ----	
# You can use the method shown in Online Appendix
# D to calculate the relevant cutpoint or you can look at the
# values in the data editor that we calculated when producing the	
# plot in Figure 5.8b. It occurs when demand is larger than 26.52

describe(data$women_leaders[data$women_leaders<26.52])
subtotal4 <- describe(data$women_leaders[data$women_leaders>26.52])$n; subtotal4

(subtotal4/total2)*100

#---- What about substantive significance of effect of supply?----
# 20 unit increase in supply when demand is at mean and max	values.	
describe(data$womens_representation[data$year==2018])
rep2018 <- describe(data$womens_representation[data$year==2018])$mean; rep2018

describe(data$labor)
labor_sd <- describe(data$labor)$sd; labor_sd

demand_mean
demand_max

summary(glht(mod1, linfct = c("(labor + leaders_labor * 52.00947)*20 = 0")))
effect_mean2 <- as.numeric(summary(glht(mod1, linfct = c("(labor + leaders_labor * 52.00947)*20 = 0")))$test[3])
(effect_mean2/rep2018)*100

summary(glht(mod1, linfct = c("(labor + leaders_labor * 91.81818)*20 = 0")))
effect_max2 <- as.numeric(summary(glht(mod1, linfct = c("(labor + leaders_labor * 91.81818)*20 = 0")))$test[3])
(effect_max2/rep2018)*100

#---- Modifying effect of demand ----
(effect_max2/effect_mean2)*100

((effect_max2-effect_mean2)/rep2018)*100

#---- Effect of one unit increase in supply when demand is at mean	and max values.	----
summary(glht(mod1, linfct = c("(labor + leaders_labor * 52.00947) = 0")))
confint(summary(glht(mod1, linfct = c("(labor + leaders_labor * 52.00947) = 0"))))

summary(glht(mod1, linfct = c("(labor + leaders_labor * 91.81818)= 0")))
confint(summary(glht(mod1, linfct = c("(labor + leaders_labor * 91.81818)= 0"))))

#---- Figure 5.9. None of the figures in the book were created in	R. ----
# To see how this figure was created, see the document	
# showing how all of the figures in the book were created.

#---- Predicted values - these give the four corners of the surface in Figure 5.9	----
summary(glht(mod1, linfct = c("(Intercept) + effectivequota*1 + polity*6 = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + effectivequota*1 + polity*6 = 0"))))

summary(glht(mod1, linfct = c("(Intercept) + women_leaders*100 + labor*111 + leaders_labor*100*111 + effectivequota*1 + polity*6 = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + women_leaders*100 + labor*111 + leaders_labor*100*111 + effectivequota*1 + polity*6 = 0"))))

summary(glht(mod1, linfct = c("(Intercept) + women_leaders*100 + effectivequota*1 + polity*6 = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + women_leaders*100 + effectivequota*1 + polity*6 = 0"))))

summary(glht(mod1, linfct = c("(Intercept) + labor*111 + effectivequota*1 + polity*6 = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + labor*111 + effectivequota*1 + polity*6 = 0"))))

#---- Some effects based on the centered standard interaction model ----
summary(mod2)

VIF(mod2)
mean(c(VIF(mod2)[1], VIF(mod2)[2], VIF(mod2)[3], VIF(mod2)[4], VIF(mod2)[5]))
1/(c(VIF(mod2)[1], VIF(mod2)[2], VIF(mod2)[3], VIF(mod2)[4], VIF(mod2)[5]))

demand_mean
supply_mean

#---- Effect of demand when supply is 0 ----
summary(glht(mod2, linfct = c("centered_women_leaders  - centered_demand_supply*67.87846 = 0")))
confint(summary(glht(mod2, linfct = c("centered_women_leaders - centered_demand_supply*67.87846 = 0"))))

#---- Effect of supply when demand is 0 ----
summary(glht(mod2, linfct = c("centered_labor - centered_demand_supply*52.00947 = 0")))
confint(summary(glht(mod2, linfct = c("centered_labor - centered_demand_supply*52.00947 = 0"))))

#---- What is constant term in uncentered model based on results from centered model?	----
summary(glht(mod2, linfct = c("(Intercept) - centered_women_leaders*52.00947 - centered_labor*67.87846 + centered_demand_supply*52.00947*67.87846 = 0")))
confint(summary(glht(mod2, linfct = c("(Intercept) - centered_women_leaders*52.00947 - centered_labor*67.87846 + centered_demand_supply*52.00947*67.87846 = 0"))))

summary(mod1)

txtStop()
