# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss) #for apply_labels
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter5_exercise2")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter5_exercise2")

txtStart("exercise2_R.txt")
#---- Load in data ----
data <- read_dta('rep_banks_2012a.dta')

#---- Summary Statistics ---- 
describe(data)

#--- Label and rename variables to match the discussion in Question 4 in the Exercises at the end of Chapter 3	----
data <- data %>%
  mutate(
    resentment_anger=anger*racresent1,
    resentment_calm = racresent1*(1-anger),
  ) %>%
  rename(
    symbolic_resentment = racresent1,
    racepolicy = racpolicy
  ) %>%
  apply_labels(
    anger = "anger",
    symbolic_resentment = "symbolic resentment",
    resentment_anger = "symbolic resentment -- angry",
    angerres1 = "anger * symbolic resentment",
    resentment_calm = "symbolic resentment -- calm"
  )

#---- Standard interaction model ----
mod1 <- lm(racepolicy ~ symbolic_resentment + anger + resentment_anger, data)
summary(mod1)
vcov(mod1)

#---- Produce a marginal effect plot for symbolic racism. ----
# Note that	the figures in the book were created using pgfplots, not R.
plot <- as.data.frame(matrix(NA, 3, 4))
colnames(plot) <- c("estimate", "lb","ub", "num")

#---- Obtain the point estimates and standard errors for the effects shown in Figure S.1 and place them in the matrix ----

plot[1, 1] <- summary(mod1)$coefficients[2, 1]
plot[1, 2] <- confint(mod1)[2, 1]
plot[1, 3] <- confint(mod1)[2, 2]

plot[2, 1] <- as.numeric(summary(glht(mod1, linfct = c("symbolic_resentment + resentment_anger = 0")))$test[[3]])
plot[2, 2] <- as.numeric(confint(glht(mod1, linfct = c("symbolic_resentment + resentment_anger = 0")))$confint[[2]])
plot[2, 3] <- as.numeric(confint(glht(mod1, linfct = c("symbolic_resentment + resentment_anger = 0")))$confint[[3]])

plot[3, 1] <- summary(mod1)$coefficients[4, 1]
plot[3, 2] <- confint(mod1)[4, 1]
plot[3, 3] <- confint(mod1)[4, 2]

plot$num <- 3:1

#---- Produce the plot using ggplot2	 ----
ggplot(plot) + 
  geom_pointrange(aes(x = num, y = estimate, ymin = lb, ymax = ub), position = position_dodge(width = 0.5), lwd = 0.4, fatten = 5, stroke = 0.4) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  labs(y = "Effect Size", x = "", shape = "", title = "") +
  theme_bw()  +
  ylim(-.1, 1.1) +
  annotate("text", y  = 0.258, x = 1.2, label = "0.258") +  
  annotate("text", y  = 0.779, x = 2.2, label = "0.779") +  
  annotate("text", y  = 0.521, x = 3.2, label = "0.521") +  
  coord_flip() + 
  scale_x_discrete(limits = c("Interaction Effect", 
                              "Symbolic Racism (Angry)",
                              "Symbolic Racism (Calm)"))


#---- Calculate the value of symbolic racism at which the standard error associated with the effect of anger is minimized. ----
summary(mod1)

b1 <- mod1$coefficients[2]; b1
b2 <- mod1$coefficients[3]; b2
b3 <- mod1$coefficients[4]; b3
varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
covb1b3 <- vcov(mod1)[2, 4]; covb1b3
covb3b2 <- vcov(mod1)[4, 3]; covb3b2

-covb3b2/varb3;
-0.01125366/0.01550988;

#---- Produce a marginal effect plot for anger. Note that the figures	in the book were created using pgfplots, not R. ----
n <- 1:101
MV2 <- (n-1)/100
conbx <- b2+b3*MV2
consx <- sqrt(varb2+varb3*(MV2^2)+2*MV2*covb3b2)

#---- Obtain degrees of freedom and critical t-value for creating	confidence intervals ----
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)
MV2 <- MV2[1:101]
conbx <- conbx[1:101]
cons <- consx[1:101]
lowerx <- lowerx[1:101]
upperx <- upperx[1:101]

#---- Draw the plot ----

ggplot() +
  geom_line(aes(x = MV2, y = conbx)) +
  geom_line(aes(x = MV2, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV2, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$symbolic_resentment, y = (..count..)/sum(..count..)*100/100), bins = 17, alpha = 0.1) +
  theme_bw() + 
  ylim(-.4, 0.4) +
  scale_y_continuous(
    name = "Marginal Effect of Anger",
    sec.axis = sec_axis(~.*100, name="Percentage of Observations")
  ) +
  xlab("Symbolic Racism") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")



#---- Figure S.2 has five vertical bars representing different quantities. ----
# The values below are slightly different but this is	only because of the rounding used in the book.
summary(glht(mod1, linfct = c("anger = 0")))
confint(summary(glht(mod1, linfct = c("anger = 0"))))

summary(glht(mod1, linfct = c("anger + resentment_anger*0.5 = 0")))
confint(summary(glht(mod1, linfct = c("anger + resentment_anger*0.5 = 0"))))

summary(glht(mod1, linfct = c("anger + resentment_anger*1 = 0")))
confint(summary(glht(mod1, linfct = c("anger + resentment_anger*1 = 0"))))

-covb3b2/varb3;

(-(2*b2*b3-2*t*t*covb3b2)+sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3))

(-(2*b2*b3-2*t*t*covb3b2)-sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3))

txtStop()
