# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter6_application2")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter6_application2")

txtStart("analysis_regime_R.txt")

#---- Load in data ----
data <- read_dta('final.dta')

#---- Variable description ----
names(data)

#---- Summary Statistics ---- 
describe(data)

#---- Make polity variable go from 0 to 20 instead of -10 to +10 ----
data$polity2 <- data$polity + 10

table(data$polity2[data$year > 1989])

#---- Create interaction terms ----
data <- data %>%
  mutate(
    leaders_labor = women_leaders*labor,
    leaders_polity2 = women_leaders*polity2,
    labor_polity2 = labor*polity2,
    leaders_labor_polity2 = women_leaders*labor*polity2,
    effectivequota_polity2 = effectivequota*polity2
  )
  
#---- Produce results shown in Table 6.3 in Chapter 6 ----
mod1 <- lm(womens_representation ~ women_leaders + labor + polity2 + 
             leaders_labor + leaders_polity2 + labor_polity2 + leaders_labor_polity2 +
             effectivequota, data)
summary(mod1)
vcov(mod1)

#---- The 3-D plot in Figure 6.17a was not created in R. ----
# The figures in the book were created using pgfplots. 

#---- Produce a figure like Figure 6.17b in R showing how the modifying effect of supply on the marginal effect of demand varies across the observed range of values for democracy. ---- 
# Note that the figures in the book were created using pgfplots, not R.

#---- Get modifying effect when democracy is at its min and max values ----
summary(glht(mod1, linfct = c("leaders_labor = 0")))
confint(summary(glht(mod1, linfct = c("leaders_labor = 0"))))

summary(glht(mod1, linfct = c("leaders_labor + leaders_labor_polity2*20 = 0")))
confint(summary(glht(mod1, linfct = c("leaders_labor + leaders_labor_polity2*20 = 0"))))

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals	----		
b1 <- summary(mod1)$coefficients[2, 1]; b1
b2 <- summary(mod1)$coefficients[3, 1]; b2
b3 <- summary(mod1)$coefficients[4, 1]; b3
b4 <- summary(mod1)$coefficients[5, 1]; b4
b5 <- summary(mod1)$coefficients[6, 1]; b5
b6 <- summary(mod1)$coefficients[7, 1]; b6
b7 <- summary(mod1)$coefficients[8, 1]; b7

varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
varb4 <- vcov(mod1)[5, 5]; varb4
varb5 <- vcov(mod1)[6, 6]; varb5
varb6 <- vcov(mod1)[7, 7]; varb6
varb7 <- vcov(mod1)[8, 8]; varb7

covb1b4 <- vcov(mod1)[2,5]; covb1b4
covb1b5 <- vcov(mod1)[2,6]; covb1b5
covb4b5 <- vcov(mod1)[5,6]; covb4b5
covb1b7 <- vcov(mod1)[2,8]; covb1b7
covb4b7 <- vcov(mod1)[5,8]; covb4b7
covb5b7 <- vcov(mod1)[6,8]; covb5b7

vcov(mod1)

n <- 1:201
MV <- (n-1)/10
conbx <- b4+b7*MV
consx <- sqrt(varb4+varb7*(MV^2)+2*MV*covb4b7)

#---- Obtain degrees of freedom and critical t-value for creating	confidence intervals ----
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)

#---- Draw the plot. The histogram differs slightly from the one shown in Figure 6.17b because the bar widths and locations are not identical. ----

ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$polity2[data$year>1989], y = (..count..)/sum(..count..)*100/1000), alpha = 0.1) +
  theme_bw() + 
  ylim(-0.02, 0.02) +
  scale_y_continuous(
    name = "Effect of Supply-Demand Interaction",
    sec.axis = sec_axis(~.*1000, name="Percentage of Observations")
  ) +
  xlab("Level of Democracy") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Information about percentage of observations in different	regions based on marginal effect plot. ----
describe(data$polity2[data$year>1989])
total <- describe(data$polity2[data$year>1989])$n; total

describe(data$polity2[data$polity2<1.6 & data$year>1989])
subtotal1 <- describe(data$polity2[data$polity2<1.6 & data$year>1989])$n; subtotal1
(subtotal1/total)*100

describe(data$polity2[data$polity2>1.6 & data$polity2<9 & data$year>1989])
subtotal2 <- describe(data$polity2[data$polity2>1.6 & data$polity2<9 & data$year>1989])$n; subtotal2
(subtotal2/total)*100

describe(data$polity2[data$polity2>9 & data$year>1989])
subtotal3 <- describe(data$polity2[data$polity2>9 & data$year>1989])$n; subtotal3
(subtotal3/total)*100

#---- Produce a figure like Figure 6.17c in R showing how the	modifying effect of democracy on the marginal effect of demand varies across the observed range of values for supply. ----
# Note 	that the figures in the book were created using pgfplots, not	R.

#---- Get modifying effect when supply is at its min and max values. ----
summary(glht(mod1, linfct = c("leaders_polity2 = 0")))
confint(summary(glht(mod1, linfct = c("leaders_polity2 = 0"))))

summary(glht(mod1, linfct = c("leaders_polity2 + leaders_labor_polity2*111 = 0")))
confint(summary(glht(mod1, linfct = c("leaders_polity2 + leaders_labor_polity2*111 = 0"))))

rm(MV, conbx, consx, lowerx, upperx)

n <- 1:1130
MV <- (n-1)/10
conbx <- b5+b7*MV
consx <- sqrt(varb5+varb7*(MV^2)+2*MV*covb5b7)
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)

#---- Limit to range of observed data. ----
MV <- MV[87:1112]
conbx <- conbx[87:1112]
lowerx <- lowerx[87:1112]
upperx <- upperx[87:1112]

ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$labor, y = (..count..)/sum(..count..)*100/200), alpha = 0.1) +
  theme_bw() + 
  ylim(-0.02, 0.02) +
  scale_y_continuous(
    name = "Effect of Demand-Democracy Interaction",
    sec.axis = sec_axis(~.*200, name="Percentage of Observations")
  ) +
  xlab("Supply") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")


#---- Information about percentage of observations in different	regions based on marginal effect plot. ----		
describe(data$labor)
total <- describe(data$labor)$n; total

describe(data$labor[data$labor<9.5])
subtotal1 <- describe(data$labor[data$labor<9.5])$n; subtotal1
(subtotal1/total)*100

describe(data$labor[data$labor>9.49 & data$labor<66.1])
subtotal2 <- describe(data$labor[data$labor>9.49 & data$labor<66.1])$n; subtotal2
(subtotal2/total)*100

describe(data$labor[data$labor>66 & data$labor<92.3])
subtotal3 <- describe(data$labor[data$labor>66 & data$labor<92.3])$n; subtotal3
(subtotal3/total)*100

describe(data$labor[data$labor>92.2])
subtotal4 <- describe(data$labor[data$labor>92.2])$n; subtotal4
(subtotal4/total)*100

#---- Produce a figure like Figure 6.18 in R showing how the	marginal effect of demand varies across the observed range of values for supply when democracy is 0 and when democracy is 20. ----
# Note that the figures in the book were created using pgfplots, not R.

#---- Get marginal effect of demand when supply and democracy are 0. ----
summary(glht(mod1, linfct = c("women_leaders = 0")))
confint(summary(glht(mod1, linfct = c("women_leaders = 0"))))

#---- Get marginal effect of demand when supply is at its max and democracy is 0 ----
summary(glht(mod1, linfct = c("women_leaders + leaders_labor*111 = 0")))
confint(summary(glht(mod1, linfct = c("women_leaders + leaders_labor*111 = 0"))))

#---- Get marginal effect of demand when supply is 0 and democracy is at its max of 20	----
summary(glht(mod1, linfct = c("women_leaders + leaders_polity2*20 = 0")))
confint(summary(glht(mod1, linfct = c("women_leaders + leaders_polity2*20 = 0"))))

#---- Get marginal effect of demand when supply is at its max and	democracy is at its max ----
summary(glht(mod1, linfct = c("women_leaders + leaders_labor*111  + leaders_polity2*20 + leaders_labor_polity2*111*20 = 0")))
confint(summary(glht(mod1, linfct = c("women_leaders + leaders_labor*111 + leaders_polity2*20 + leaders_labor_polity2*111*20 = 0"))))

#---- Figure 6.18a - Democracy is 0 ----
rm(conbx, consx, lowerx, upperx)
conbx <- b1+b4*MV+b5*0+b7*MV*0
consx <- sqrt(varb1 + (MV^2)*varb4 + (0^2)*varb5 + (MV^2)*(0^2)*varb7
              + 2*MV*covb1b4 + 2*0*covb1b5 + 2*MV*0*covb1b7 + 2*MV*0*covb4b5
              + 2*(MV^2)*0*covb4b7 + 2*MV*(0^2)*covb5b7)
lowerx <- conbx-(t*consx)
upperx <- conbx+(t*consx)

ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$labor[data$polity2==0], y = (..count..)/sum(..count..)*100/25), bins = 11, alpha = 0.1) +
  theme_bw() + 
  ylim(-0.6, 1.2) +
  scale_y_continuous(
    name = "Effect of Demand|Democracy = 0",
    sec.axis = sec_axis(~.*25, name="Percentage of Observations")
  ) +
  xlab("Supply") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Modifying effect of supply on marginal effect of demand when democracy is 0 ----
summary(glht(mod1, linfct = c("leaders_labor = 0")))
confint(summary(glht(mod1, linfct = c("leaders_labor = 0"))))

#---- Figure 6.18ab - Democracy is 20	----
conbx2 <- b1+b4*MV+b5*20 +b7*MV*20
consx2 <- sqrt(varb1 + (MV^2)*varb4 + (20^2)*varb5 + (MV^2)*(20^2)*varb7
               + 2*MV*covb1b4 + 2*20*covb1b5 + 2*MV*20*covb1b7 + 2*MV*20*covb4b5
               + 2*(MV^2)*20*covb4b7 + 2*MV*(20^2)*covb5b7)
lowerx2 <- conbx2-(t*consx2)
upperx2 <- conbx2+(t*consx2)

ggplot() +
  geom_line(aes(x = MV, y = conbx2)) +
  geom_line(aes(x = MV, y = upperx2), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx2), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$labor[data$polity2==20], y = (..count..)/sum(..count..)*100/25), bins = 50, alpha = 0.1) +
  theme_bw() + 
  ylim(-1.2, 1.2) +
  scale_y_continuous(
    name = "Effect of Demand|Democracy = 20",
    sec.axis = sec_axis(~.*25, name="Percentage of Observations")
  ) +
  xlab("Supply") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#----  Modifying effect of supply on marginal effect of demand when democracy is 0 ----
summary(glht(mod1, linfct = c("leaders_labor + leaders_labor_polity2*20 = 0")))
confint(summary(glht(mod1, linfct = c("leaders_labor + leaders_labor_polity2*20 = 0"))))

#---- Percentage of observations where effect of demand is negative and statistically significant when democracy is 20 ----
describe(data$polity2[data$polity2==20])
total2 <- describe(data$polity2[data$polity2==20])$n; total2

describe(data$polity2[data$polity2==20 & data$labor<42.3])
subtotal5 <- describe(data$polity2[data$polity2==20 & data$labor<42.3])$n; subtotal5
(subtotal5/total2)*100

#---- What about substantive significance of effect of demand? ----

#---- Calculate information to produce Figure 6.19 ----
describe(data$labor)
labor_mean <- describe(data$labor)$mean; labor_mean
labor_max <- describe(data$labor)$max; labor_max

describe(data$womens_representation[data$polity2==0])
rep_mindem <- describe(data$womens_representation[data$polity2==0])$mean; rep_mindem
describe(data$womens_representation[data$polity2==20])
rep_maxdem <- describe(data$womens_representation[data$polity2==20])$mean; rep_maxdem

#---- 20 unit increase in demand when supply is mean and democracy is 0 ----
summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*67.87846 )*20 = 0")))
confint(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*67.87846)*20 = 0"))))

(((mod1$coefficients[2] +mod1$coefficients[5]*labor_mean+mod1$coefficients[6]*0+
     mod1$coefficients[8]*labor_mean*0)*20)/rep_mindem)*100

#---- 20 unit increase in demand when supply is mean and democracy is	20	----
summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*67.87846 + leaders_polity2*20 + leaders_labor_polity2*67.87846*20)*20 = 0")))
confint(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*67.87846 + leaders_polity2*20 + leaders_labor_polity2*67.87846*20)*20 = 0"))))

#---- 20 unit increase in demand when supply is max and democracy is 0 ----
summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*111.0102)*20 = 0")))
confint(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*111.0102)*20 = 0"))))

#---- 20 unit increase in demand when supply is max and democracy is 20 ----
summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*111.0102 + leaders_polity2*20 + leaders_labor_polity2*111.0102*20)*20 = 0")))
confint(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*111.0102 + leaders_polity2*20 + leaders_labor_polity2*111.0102*20)*20 = 0"))))

(((mod1$coefficients[2] +mod1$coefficients[5]*labor_max+mod1$coefficients[6]*20+
     mod1$coefficients[8]*labor_max*20)*20)/rep_maxdem)*100

#---- Differences	----
summary(glht(mod1, linfct = c("(leaders_polity2*20 + leaders_labor_polity2*67.87846*20)*20 = 0")))
confint(summary(glht(mod1, linfct = c("(leaders_polity2*20 + leaders_labor_polity2*67.87846*20)*20 = 0"))))

summary(glht(mod1, linfct = c("(leaders_polity2*20 + leaders_labor_polity2*111.0102*20)*20 = 0")))
confint(summary(glht(mod1, linfct = c("(leaders_polity2*20 + leaders_labor_polity2*111.0102*20)*20 = 0"))))

((((mod1$coefficients[2]+mod1$coefficients[5]*labor_max+mod1$coefficients[6]*20 +
      mod1$coefficients[8]*labor_max*20)*20) -((mod1$coefficients[2] +mod1$coefficients[5]*labor_max+mod1$coefficients[6]*0 +
                                                  mod1$coefficients[8]*labor_max*0)*20))/rep_maxdem)*100

labor_max - labor_mean
summary(glht(mod1, linfct = c("(leaders_labor*43.13174 + leaders_labor_polity2*43.13174*20)*20 = 0")))
confint(summary(glht(mod1, linfct = c("(leaders_labor*43.13174 + leaders_labor_polity2*43.13174*20)*20 = 0"))))

((((mod1$coefficients[2]+mod1$coefficients[5]*labor_max+mod1$coefficients[6]*20 +
      mod1$coefficients[8]*labor_max*20)*20) -((mod1$coefficients[2] +mod1$coefficients[5]*labor_mean+mod1$coefficients[6]*20 +
       mod1$coefficients[8]*labor_mean*20)*20))/rep_maxdem)*100

summary(glht(mod1, linfct = c("leaders_labor*43.13174*20 = 0")))
confint(summary(glht(mod1, linfct = c("leaders_labor*43.13174*20 = 0"))))

#---- Difference in differences ----
summary(glht(mod1, linfct = c("leaders_labor_polity2*43.13174*20*20 = 0")))
confint(summary(glht(mod1, linfct = c("leaders_labor_polity2*43.13174*20*20 = 0"))))

summary(glht(mod1, linfct = c("leaders_labor_polity2*43.13174*20*20 = 0")))
confint(summary(glht(mod1, linfct = c("leaders_labor_polity2*43.13174*20*20 = 0"))))

txtStop()
