# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss) #for apply_labels
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter7_application1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter7_application1")

txtStart("sentiment_R.txt")

#---- Load in data ----
data <- read_dta('sentiment.dta')

#---- Create quadratic ideology term ----
data <- data %>%
  mutate(left_right2 = left_right*left_right) %>%
  apply_labels(left_right2 = "left_right*left_right")

#---- Variable description ----
names(data)

#---- Summary Statistics ---- 
describe(data)
describe(data$positive_sentiment)

#---- Produce results shown in Table 7.1 in Chapter 7 ----
mod1 <- lm(positive_sentiment ~ left_right + left_right2, data)
summary(mod1)

#---- Calculate value of left-right at which positive sentiment is maximized. ----
- mod1$coefficients[2] / (2 * mod1$coefficients[3])

#--- Produce a predicted value plot similar to the one shown in	Figure 7.4a. ----
# Note that the figures in the book were created using pgfplots, not R.
summary(mod1)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals	----		
b1 <- summary(mod1)$coefficients[2, 1]; b1
b2 <- summary(mod1)$coefficients[3, 1]; b2
b0 <- summary(mod1)$coefficients[1, 1]; b1

varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb0 <- vcov(mod1)[1, 1]; varb0

covb1b0 <- vcov(mod1)[2,1]; covb1b0
covb1b2 <- vcov(mod1)[2,3]; covb1b2
covb2b0 <- vcov(mod1)[3,1]; covb2b0

vcov(mod1)

n <- 1:102
MV <- (n-1)/10
predy <- b0+b1*MV+b2*MV*MV
cons_predy <- sqrt(varb0+varb1*(MV^2)+varb2*(MV^4)+2*MV*covb1b0+2*MV*MV*covb2b0+2*MV*MV*MV*covb1b2)
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- predy - (t*cons_predy)
upperx <- predy + (t*cons_predy)

#---- Double check predicted value when left-right is 5. ----
summary(glht(mod1, linfct = c("(Intercept) + 5*left_right + 25*left_right2 = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + 5*left_right + 25*left_right2 = 0"))))

predict(mod1, newdata = data.frame(left_right = 5, left_right2 = 25), se.fit=TRUE, interval="confidence")

#---- Produce the plot in Figure 7.4a. ----
# The histogram will be a little	different due to different bar widths and locations.
ggplot() +
  geom_line(aes(x = MV, y = predy)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$left_right, y = (..count..)/sum(..count..)*100/10), bins=14,alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Positive Sentiment",
    sec.axis = sec_axis(~.*10, name="Percentage of Observations")
  ) +
  xlab("Left-Right Position") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")


#---- Numerically look at the value of left-right where predicted	positive sentiment is maximized. ----
describe(predy)
predy_max <- describe(predy)$max; predy_max
MV[predy == predy_max]

#---- Produce a marginal effect plot for left-right similar to the one shown in Figure 7.4b. ----
# Note that the figures in the book were created using pgfplots, not R. 
rm(lowerx, upperx, MV)
n <- 1:1001
MV <- (n-1)/100
conb <- b1+2*b2*MV 
cons <- sqrt(varb1+varb2*4*MV*MV+4*MV*covb1b2)
lowerx <- conb - (t*cons)
upperx <- conb + (t*cons)

#---- Double check marginal effect when left-right is 5. ----
summary(glht(mod1, linfct = c("left_right + 2*left_right2*5 = 0")))
confint(summary(glht(mod1, linfct = c("left_right + 2*left_right2*5 = 0"))))

#---- Produce the plot in Figure 7.4b. ----
#The histogram will be a little	different due to different bar widths and locations. ----
ggplot() +
  geom_line(aes(x = MV, y = conb)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$left_right, y = (..count..)/sum(..count..)*100/20), bins=14,alpha = 0.1) +
  theme_bw() +
  scale_y_continuous(
    name = "Positive Sentiment",
    sec.axis = sec_axis(~.*20, name="Percentage of Observations")
  ) +
  xlab("Left-Right Position") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Percentage of observations that fall into the different regions	in the plot using the cutpoints identified in the data editor. ----
describe(data$left_right)
total <- describe(data$left_right)$n; total

describe(data$year[data$left_right<4.69 & !is.na(data$left_right)])
subtotal <- describe(data$year[data$left_right<4.69 & !is.na(data$left_right)])$n; subtotal
(subtotal/total)*100

describe(data$year[data$left_right>5.68 & !is.na(data$left_right)])
subtotal2 <- describe(data$year[data$left_right>5.68 & !is.na(data$left_right)])$n; subtotal2
(subtotal2/total)*100

#---- Produce a first difference plot for left-right similar to the one shown in Figure 7.4c. ----
# Note that the figures in the book	were created using pgfplots, not R.	
rm(lowerx, upperx, conb, cons)
conb <- b1+b2+2*b2*MV
cons <- sqrt(varb1+(1+4*MV+4*MV*MV)*varb2+ (2+4*MV)*covb1b2)
lowerx <- conb - (t*cons)
upperx <- conb + (t*cons)

#---- Double check first difference when left-right is 5. ----
summary(glht(mod1, linfct = c("left_right + left_right2*11 = 0")))
confint(summary(glht(mod1, linfct = c("left_right + left_right2*11 = 0"))))

#---- Produce the plot in Figure 7.4b. The histogram will be a little	different due to different bar widths and locations. ----
ggplot() +
  geom_line(aes(x = MV, y = conb)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$left_right, y = (..count..)/sum(..count..)*100/20), bins=14,alpha = 0.1) +
  theme_bw() +
  scale_y_continuous(
    name = "Positive Sentiment",
    sec.axis = sec_axis(~.*20, name="Percentage of Observations")
  ) +
  xlab("Left-Right Position") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Percentage of observations that fall into the different regions	in the plot using the cutpoints identified in the data editor.
describe(data$left_right)
total <- describe(data$left_right)$n; total

describe(data$year[data$left_right<4.19 & !is.na(data$left_right)])
subtotal <- describe(data$year[data$left_right<4.19 & !is.na(data$left_right)])$n; subtotal
(subtotal/total)*100

describe(data$year[data$left_right>5.18 & !is.na(data$left_right)])
subtotal2 <- describe(data$year[data$left_right>5.18 & !is.na(data$left_right)])$n; subtotal2
(subtotal2/total)*100

#---- Substantive significance -- effect of a one unit increase in left-right when left-right is 2. ----
# We can look at the information in the data editor, or calculate it manually like below.
describe(data$left_right)
leftright_sd <- describe(data$left_right)$sd; leftright_sd
(1/leftright_sd) * 100

b1+b2+2*b2*2
(b1+b2+2*b2*2)-(t*(sqrt(varb1+(1+4*2+4*2*2)*varb2+ (2+4*2)*covb1b2)))
(b1+b2+2*b2*2)+(t*(sqrt(varb1+(1+4*2+4*2*2)*varb2+ (2+4*2)*covb1b2)))

describe(data$positive_sentiment[data$left_right<=2 & !is.na(data$left_right)])
sentiment_m <- describe(data$positive_sentiment[data$left_right<=2 & !is.na(data$left_right)])$mean; sentiment_m
((b1+b2+2*b2*2)/sentiment_m)*100

#---- Substantive significance -- effect of a one unit increase in left-right when left-right is at its mean value. ----
describe(data$left_right)
left_right_mean <- describe(data$left_right)$mean; left_right_mean

b1+b2+2*b2*left_right_mean

sqrt(varb1+(1+4*left_right_mean+4*left_right_mean*left_right_mean)*varb2+ (2+4*left_right_mean)*covb1b2)

(b1+b2+2*b2*left_right_mean)-(t*(sqrt(varb1+(1+4*left_right_mean+4*left_right_mean*left_right_mean)*varb2+ (2+4*left_right_mean)*covb1b2)))

(b1+b2+2*b2*left_right_mean)+(t*(sqrt(varb1+(1+4*left_right_mean+4*left_right_mean*left_right_mean)*varb2+ (2+4*left_right_mean)*covb1b2)))

txtStop()