# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss) #for apply_labels
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter8_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter8_application")

txtStart("pec_R.txt")

#---- Load in data ----
data <- read_dta('pec_BJPS.dta')

#---- Get polarization and threshold measures by election. ----
mean_data <- data %>%
  group_by(election) %>%
  dplyr::select(threshold, polarization) %>%
  summarise(across(threshold:polarization, mean))

describe(mean_data$threshold)
threshold_mean <- describe(mean_data$threshold)$mean; threshold_mean
threshold_sd <- describe(mean_data$threshold)$sd; threshold_sd

describe(mean_data$polarization)
polarization_mean <- describe(mean_data$polarization)$mean; polarization_mean
polarization_sd <- describe(mean_data$polarization)$sd; polarization_sd

describe(mean_data$election)
election_total <- describe(mean_data$election)$n; election_total

describe(mean_data$election[mean_data$threshold>16.74 & !is.na(mean_data$threshold)])
election_subtotal <- describe(mean_data$election[mean_data$threshold>16.74 & !is.na(mean_data$threshold)])$n; election_subtotal
(election_subtotal/election_total)*100

#---- Create some variables ----
data <- data %>%
  mutate(
    coalitionseatlag = seatlag1 + seatlag2,
    seatshare = coalitionseatlag*100,
    seatshare_2 = seatshare*seatshare,
    polarization_threshold = polarization*threshold) %>%
  apply_labels(
    seatshare = "size of potential coalition in percentage of seats",
    seatshare_2 = "seatshare squared"
  )

#---- Summary statistics ----
names(data)

data_sub <- dplyr::select(data, pec, seatshare, incompatibility, polarization, threshold)
describe(data_sub)

table(data$pec)

describe(data$polarization[data$polarization<83.7])

#---- Produce results shown in Table 8.2 in Chapter 8	----
mod1 <- glm(pec ~ threshold + polarization + polarization_threshold + seatshare +
              seatshare_2 + incompatibility, data, family = binomial(link = "logit"))
summary(mod1)
exp(cbind(OR = coef(mod1), confint(mod1)))

#---- Produce a figure like Figure 8.10a in R showing how the	marginal effect of disproportionality varies across the observed range of values for party system polarization. ----
# Note that the figures in the book were created using pgfplots, not R.
summary(mod1)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals	----		
b1 <- summary(mod1)$coefficients[2, 1]; b1
b2 <- summary(mod1)$coefficients[3, 1]; b2
b3 <- summary(mod1)$coefficients[4, 1]; b3
b4 <- summary(mod1)$coefficients[5, 1]; b4
b5 <- summary(mod1)$coefficients[6, 1]; b5

varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
varb4 <- vcov(mod1)[5, 5]; varb4
varb5 <- vcov(mod1)[6, 6]; varb5

covb1b3 <- vcov(mod1)[2,4]; covb1b3
covb3b2 <- vcov(mod1)[4,3]; covb3b2
covb4b5 <- vcov(mod1)[5,6]; covb4b5

vcov(mod1)

n <- 1:101
MV <- n-1
conbx <- b1+b3*MV
consx <- sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3)

#---- Obtain critical z-value for creating confidence intervals ----
z <- qnorm(0.975)
lowerx <- conbx-(z*consx)
upperx <- conbx+(z*consx)

#---- Draw the plot. The histogram differs slightly from the one shown in Figure 8.10a because the bar widths and locations are not identical. ----

ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$polarization, y = (..count..)/sum(..count..)*100/100), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Marginal Effect of Disproportionality",
    sec.axis = sec_axis(~.*100, name="Percentage of Observations")
  ) +
  xlab("Party System Polarization") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

rm(MV, conbx, consx, upperx, lowerx)

#---- Produce a figure like Figure 8.10b in R showing how the	marginal effect of polarization varies across the observed range of values for disproportionality. ----
# Note that the figures in the book were created using pgfplots, not R.
mod1 <- glm(pec ~ polarization + threshold + polarization_threshold + seatshare +
              seatshare_2 + incompatibility, data, family = binomial(link = "logit"))
summary(mod1)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals	----		
b1 <- summary(mod1)$coefficients[2, 1]; b1
b2 <- summary(mod1)$coefficients[3, 1]; b2
b3 <- summary(mod1)$coefficients[4, 1]; b3

varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3

covb1b3 <- vcov(mod1)[2,4]; covb1b3
covb3b2 <- vcov(mod1)[4,3]; covb3b2


vcov(mod1)

n <- 1:3501
MV <- (n-1)/100
conbx <- b1+b3*MV
consx <- sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3)
z <- qnorm(0.975)
lowerx <- conbx-(z*consx)
upperx <- conbx+(z*consx)

#---- Draw the plot. The histogram differs slightly from the one shown in Figure 8.10b because the bar widths and locations are not identical. ---- 
# It also differs because the histogram in Figure	
# 8.10b in the book shows information about electoral system 	
# disproportionality per election. Electoral system
# disproportionality is a characteristic of the election not a
# characteristic of the potential coalition dyad.
ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$threshold, y = (..count..)/sum(..count..)*100/1000), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Marginal Effect of Polarization",
    sec.axis = sec_axis(~.*1000, name="Percentage of Observations")
  ) +
  xlab("Electoral System Disproportionality") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

rm(MV, conbx, consx, upperx, lowerx)

#---- Calculate coalition size that maximizes propensity of PEC formation. ----
-mod1$coefficients[5]/(2*mod1$coefficients[6])

#---- Produce a figure like Figure 8.11a in R showing how the	marginal effect of coalition size varies across the observed range of values for coalition size. ----
# Note that the figures in the book were created using pgfplots, not R.
mod1 <- glm(pec ~ threshold + polarization + polarization_threshold + seatshare +
              seatshare_2 + incompatibility, data, family = binomial(link = "logit"))
summary(mod1)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals	----		
b0 <- summary(mod1)$coefficients[1, 1]; b0
b1 <- summary(mod1)$coefficients[2, 1]; b1
b2 <- summary(mod1)$coefficients[3, 1]; b2
b3 <- summary(mod1)$coefficients[4, 1]; b3
b4 <- summary(mod1)$coefficients[5, 1]; b4
b5 <- summary(mod1)$coefficients[6, 1]; b5
b6 <- summary(mod1)$coefficients[7, 1]; b6
varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
varb4 <- vcov(mod1)[5, 5]; varb4
varb5 <- vcov(mod1)[6, 6]; varb5

covb1b3 <- vcov(mod1)[2,4]; covb1b3
covb3b2 <- vcov(mod1)[4,3]; covb3b2
covb4b5 <- vcov(mod1)[5,6]; covb4b5

vcov(mod1)

n <- 1:1001
MV <- (n-1)/10
conbx <- b4+b5+2*b5*MV
consx <- sqrt(varb4+(1+4*MV+4*MV*MV)*varb5+ (2+4*MV)*covb4b5)
z <- qnorm(0.975)
lowerx <- conbx-(z*consx)
upperx <- conbx+(z*consx)

#---- Double check effect when coalition size is 40 ----
summary(glht(mod1, linfct = c("seatshare + 81*seatshare_2 = 0")))
confint(summary(glht(mod1, linfct = c("seatshare + 81*seatshare_2 = 0"))))

#---- Draw the plot. The histogram differs slightly from the one shown in Figure 8.11a because the bar widths and locations are not identical. ----

ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$seatshare, y = (..count..)/sum(..count..)*100/100), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of Coaltion Size",
    sec.axis = sec_axis(~.*100, name="Percentage of Observations")
  ) +
  xlab("Expected Coalition Size") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Information about percentage of observations in different regions based on marginal effect plot. ----
describe(data$seatshare)
total <- describe(data$seatshare)$n; total

describe(data$seatshare[data$seatshare<27.3])
subtotal1 <- describe(data$seatshare[data$seatshare<27.3])$n; subtotal1
(subtotal1/total)*100

describe(data$seatshare[data$seatshare>45.9 & !is.na(data$seatshare)])
subtotal2 <- describe(data$seatshare[data$seatshare>45.9 & !is.na(data$seatshare)])$n; subtotal2
(subtotal2/total)*100

#---- Identify values to be used for histogram in Figures 8.11a and 8.11b	----
describe(data$seatshare[data$seatshare>-0.01 & data$seatshare<5])
subtotal <- describe(data$seatshare[data$seatshare>-0.01 & data$seatshare<5])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>4.999 & data$seatshare<10])
subtotal <- describe(data$seatshare[data$seatshare>4.999 & data$seatshare<10])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>9.999 & data$seatshare<15])
subtotal <- describe(data$seatshare[data$seatshare>9.999 & data$seatshare<15])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>14.999 & data$seatshare<20])
subtotal <- describe(data$seatshare[data$seatshare>14.999 & data$seatshare<20])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>19.999 & data$seatshare<25])
subtotal <- describe(data$seatshare[data$seatshare>19.999 & data$seatshare<25])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>24.999 & data$seatshare<30])
subtotal <- describe(data$seatshare[data$seatshare>24.999 & data$seatshare<30])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>29.999 & data$seatshare<35])
subtotal <- describe(data$seatshare[data$seatshare>29.999 & data$seatshare<35])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>34.999 & data$seatshare<40])
subtotal <- describe(data$seatshare[data$seatshare>34.999 & data$seatshare<40])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>39.999 & data$seatshare<45])
subtotal <- describe(data$seatshare[data$seatshare>39.999 & data$seatshare<45])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>44.999 & data$seatshare<50])
subtotal <- describe(data$seatshare[data$seatshare>44.999 & data$seatshare<50])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>49.999 & data$seatshare<55])
subtotal <- describe(data$seatshare[data$seatshare>49.999 & data$seatshare<55])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>54.999 & data$seatshare<60])
subtotal <- describe(data$seatshare[data$seatshare>54.99 & data$seatshare<60])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>59.999 & data$seatshare<65])
subtotal <- describe(data$seatshare[data$seatshare>59.999 & data$seatshare<65])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>64.999 & data$seatshare<70])
subtotal <- describe(data$seatshare[data$seatshare>64.999 & data$seatshare<70])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>69.999 & data$seatshare<75])
subtotal <- describe(data$seatshare[data$seatshare>69.999 & data$seatshare<75])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>74.999 & data$seatshare<80])
subtotal <- describe(data$seatshare[data$seatshare>74.999 & data$seatshare<80])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>79.999 & data$seatshare<85])
subtotal <- describe(data$seatshare[data$seatshare>79.999 & data$seatshare<85])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>84.999 & data$seatshare<89])
subtotal <- describe(data$seatshare[data$seatshare>84.999 & data$seatshare<89])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>89.999 & data$seatshare<95])
subtotal <- describe(data$seatshare[data$seatshare>89.999 & data$seatshare<95])$n; subtotal
(subtotal/total)*100

describe(data$seatshare[data$seatshare>94.999 & data$seatshare<100.01])
subtotal <- describe(data$seatshare[data$seatshare>94.999 & data$seatshare<100.01])$n; subtotal
(subtotal/total)*100

rm(MV, conbx, consx, upperx, lowerx)

#---- Produce a figure like Figure 8.11b in R showing how the predicted propensity of PEC formation varies across the observed range of values for coalition size when Disproportionality, Polarization, and Ideological	Incompatibility are all at their mean values. ----
describe(data$incompatibility)
incompatibility_mean <- describe(data$incompatibility)$mean; incompatibility_mean

n <- 1:1001
MV <- (n-1)/10
predy <- b0+b1*threshold_mean+b2*polarization_mean+b3*threshold_mean*polarization_mean+b4*MV+b5*MV*MV + b6*incompatibility_mean

#---- Double check predicted value when seatshare  is 20.	----
summary(glht(mod1, linfct = c("(Intercept) + threshold*14.19207 + polarization*29.47747 + polarization_threshold*14.19207*29.47747 +seatshare*20 + seatshare_2*400 + incompatibility*24.40688 = 0")))
confint(summary(glht(mod1, linfct = c("(Intercept) + threshold*14.19207 + polarization*29.47747 + polarization_threshold*14.19207*29.47747 +seatshare*20 + seatshare_2*400 + incompatibility*24.40688 = 0"))))

#---- Produce the plot in Figure 8.11b. The histogram will be a little different due to different bar widths and locations.. ----
ggplot() +
  geom_line(aes(x = MV, y = predy)) +
  geom_histogram(aes(x = data$seatshare, y = (..count..)/sum(..count..)*100*-0.5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "PEC*",
    sec.axis = sec_axis(~./-0.5, name="Percentage of Observations")
  ) +
  xlab("Expected Coalition Size") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Numerically look at the value of seatshare where PEC* is maximized. ----
describe(predy)
predy_max <- describe(predy)$max; predy_max
MV[predy==predy_max]

#---- And precisely ... ----
-b4/(2*b5)

txtStop()
