# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "msm", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss) #for apply_labels
library(msm) #for deltamethod
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter8_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter8_application")

txtStart("pec3_R.txt")

#---- Load in data ----
data <- read_dta('pec_BJPS.dta')

#---- Get polarization and threshold measures by election. ----
mean_data <- data %>%
  group_by(election) %>%
  dplyr::select(polarization) %>%
  summarise(across(polarization, mean))


describe(mean_data$polarization)
polarization_sd <- describe(mean_data$polarization)$sd; polarization_sd


#---- Create some variables ----
data <- data %>%
  mutate(
    coalitionseatlag = seatlag1 + seatlag2,
    seatshare = coalitionseatlag*100,
    seatshare_2 = seatshare*seatshare,
    polarization_threshold = polarization*threshold) %>%
  apply_labels(
    seatshare = "size of potential coalition in percentage of seats",
    seatshare_2 = "seatshare squared"
  )

#---- Summary statistics ----
names(data)

data_sub <- dplyr::select(data, pec, seatshare, incompatibility, polarization, threshold)
describe(data_sub)

table(data$pec)

#---- Produce results shown in Table 8.2 in Chapter 8	----
mod1 <- glm(pec ~ threshold + polarization + polarization_threshold + seatshare +
              seatshare_2 + incompatibility, data, family = binomial(link = "logit"))
summary(mod1)
exp(cbind(OR = coef(mod1), confint(mod1)))

#---- Produce a figure like Figure 8.15 in R.----
# Percentage change in the odds of PEC formation associated with a one standard
# deviation increase in Polarization.
odds_hat <- vector()
odds_lo <- vector()
odds_hi <- vector()

a <- 0
j <- 1
while(a <= 35.2){
 odds_hat[j] <- exp((mod1$coefficients[3] + mod1$coefficients[4]*a)*polarization_sd)
 mid <- (mod1$coefficients[3] + mod1$coefficients[4]*a)*polarization_sd
 se <- deltamethod(~ ((x3 + x4*a)*polarization_sd), coef(mod1), vcov(mod1))
 odds_lo[j] <- exp(mid - se*qnorm(0.975))
 odds_hi[j] <- exp(mid + se*qnorm(0.975))
 a <- a + 0.1
 j <- j + 1
 
}

sim_data <- as.data.frame(cbind(odds_hat, odds_lo, odds_hi))
sim_data <- sim_data[1:351, ]
n <- 1:351
MV <- (n-1)/10

#---- Graph odds ratio associated with a one standard deviation increase in Polarization. ----
# The histogram differs slightly from 	
# the one in Figure 8.15 because the bar widths and locations are 
# not identical. It also differs because the histogram in Figure	
# 8.15 in the book shows information about electoral system 		
# disproportionality per election. Electoral system 		
# disproportionality is a characteristic of the election not a
# characteristic of the potential coalition dyad.		

ggplot() +
  geom_line(aes(x = MV, y = sim_data$odds_hat)) +
  geom_line(aes(x = MV, y = sim_data$odds_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$odds_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$threshold, y = (..count..)/sum(..count..)*100/12.5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Odds of Pre-Electoral Coalition Formation",
    sec.axis = sec_axis(~.*12.5, name="Percentage of Observations")
  ) +
  xlab("Electoral System Disproportionality") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 1, lty = "solid")

#---- Get percentage change in odds ----
odds_percent <- (sim_data$odds_hat-1)*100
odds_percent_lo <- (sim_data$odds_lo-1)*100
odds_percent_hi <- (sim_data$odds_hi-1)*100

#---- Figure 8.15 ----
ggplot() +
  geom_line(aes(x = MV, y = odds_percent)) +
  geom_line(aes(x = MV, y = odds_percent_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = odds_percent_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$threshold, y = (..count..)/sum(..count..)*100*4), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Percentage Change in Odds of Pre-Electoral Coalition Formation",
    sec.axis = sec_axis(~./4, name="Percentage of Observations")
  ) +
  xlab("Electoral System Disproportionality") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 1, lty = "solid")

#---- Some specific values ----
c(MV[n == 143], odds_percent[n==143], odds_percent_lo[n==143], odds_percent_hi[n==143])
mean <- odds_percent[n==143]; mean

c(MV[n == 276], odds_percent[n==276], odds_percent_lo[n==276], odds_percent_hi[n==276])
meanplus <- odds_percent[n==276]; meanplus

((meanplus/mean)-1)*100

rm(odds_percent, odds_percent_lo, odds_percent_hi, odds_hat, odds_lo, odds_hi, MV)

# Rather than use R's deltamethod command, we could do this manually via simulation	
summary(mod1)

set.seed(10101)
sim <- mvrnorm(n = 10000, mu = mod1$coefficients, Sigma = vcov(mod1))

odds_hat <- vector()
odds_lo <- vector()
odds_hi <- vector()
odds_percent <- vector()
odds_percent_lo <- vector()
odds_percent_hi <- vector()

a <- 0
j <- 1
while(a <= 35){
  
  x_betahat <- (sim[,  3] + sim[, 4]*a)*polarization_sd
  odds <- exp(x_betahat)
  oddspercent <- (exp(x_betahat)-1)*100
  
  oddshat <- mean(odds)
  oddspercenthat <- mean(oddspercent)
  
  odds_lo[j] <- quantile(odds, 0.025)
  odds_hi[j] <- quantile(odds, 0.975)
  odds_hat[j] <- oddshat

  odds_percent_lo[j] <- quantile(oddspercent, 0.025)
  odds_percent_hi[j] <- quantile(oddspercent, 0.975)
  odds_percent[j] <- oddspercenthat
  
  a <- a + 0.1
  j <- j + 1
  
}

sim_data <- as.data.frame(cbind(odds_hat, odds_lo, odds_hi, odds_percent, odds_percent_lo, odds_percent_hi))

sim_data <- sim_data[1:350, ]
n <- 1:350
MV <- (n-1)/10

ggplot() +
  geom_line(aes(x = MV, y = sim_data$odds_percent)) +
  geom_line(aes(x = MV, y = sim_data$odds_percent_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$odds_percent_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$threshold, y = (..count..)/sum(..count..)*100*4), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Percentage Change in Odds of Pre-Electoral Coalition Formation",
    sec.axis = sec_axis(~./4, name="Percentage of Observations")
  ) +
  xlab("Electoral System Disproportionality") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 1, lty = "solid")

txtStop()