# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "MASS", "aod", "msm", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation and ggplot
library(psych) #to describe data
library(multcomp) #for glht
library(MASS) #polr
library(aod) #for wald.test
library(msm) #for deltamethod
library(TeachingDemos) #for txtStart

# Set working directory
setwd("~/Dropbox/ali/replications/chapter9_application")
#setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter9_application")

txtStart("anes2012_analysis_approval_R.txt")

#---- Load in data ----
data <- read_dta('anes2012_small.dta')

#---- Variable description ----
names(data)
describe(data)

#---- Drop respondents who are not white or black ----
data <- filter(data, white == 1 | black == 1)

#---- interaction term for race and ideological distance ----
data$black_leftright = data$left_right * data$black

#---- Produce results shown in Table 9.1 in Chapter 9	----
mod1 <- polr(as.factor(obama_approval) ~ left_right + black + black_leftright +
             worse_off_national + female + age, data)
summary(mod1)
exp(cbind(OR = coef(mod1), confint(mod1)))
names(mod1)
summary(mod1)$coefficients
vcov(mod1)

#---- Check that cutpoints are different ----
wald.test(Sigma = vcov(mod1), b = summary(mod1)$coefficients[ , 1], Terms = 7:8)
wald.test(Sigma = vcov(mod1), b = summary(mod1)$coefficients[ , 1], Terms = 8:9)

#---- Produce a figure like Figure 9.4a in R showing how the effect of a one unit increase in ideology on the propensity to	approve of Obama varies by race ----
summary(mod1)

#---- Create a 3 x 4 matrix to store inputs for creating plot	----
plot <- matrix(NA, 3, 4)
colnames(plot) <- c("estimate", "lb", "ub", "num")

#---- Obtain the point estimates and standard errors for the effects shown in Figure 9.4a and place them in the matrix ----
summary(glht(mod1, linfct = c("black_leftright = 0")))
plot[1, 1] <- as.numeric(summary(glht(mod1, linfct = c("black_leftright = 0")))$test[3])
plot[1, 2] <- as.numeric(confint(glht(mod1, linfct = c("black_leftright = 0")))$confint[[2]])
plot[1, 3] <- as.numeric(confint(glht(mod1, linfct = c("black_leftright = 0")))$confint[[3]])

summary(glht(mod1, linfct = c("left_right = 0")))
plot[2, 1] <- as.numeric(summary(glht(mod1, linfct = c("left_right = 0")))$test[3])
plot[2, 2] <- as.numeric(confint(glht(mod1, linfct = c("left_right = 0")))$confint[[2]])
plot[2, 3] <- as.numeric(confint(glht(mod1, linfct = c("left_right = 0")))$confint[[3]])

summary(glht(mod1, linfct = c("left_right + black_leftright = 0")))
plot[3, 1] <- as.numeric(summary(glht(mod1, linfct = c("left_right + black_leftright = 0")))$test[3])
plot[3, 2] <- as.numeric(confint(glht(mod1, linfct = c("left_right + black_leftright = 0")))$confint[[2]])
plot[3, 3] <- as.numeric(confint(glht(mod1, linfct = c("left_right + black_leftright = 0")))$confint[[3]])

plot[ , 4] <- c(3:1)

#---- Produce Figure 9.4a using ggplot2 ----
ggplot(data.frame(plot)) + 
  geom_pointrange(aes(x = num, y = estimate, ymin = lb, ymax = ub)) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  ylim(-1.2, 1) +
  labs(y = "Effect Size", x = "", shape = "", title = "") +
  theme_bw()  +
  annotate("text", y  = 0.78, x = 3.2, label = "0.78") +  
  annotate("text", y  = -1.01, x = 2.2, label = "-1.01") +  
  annotate("text", y  = -0.22, x = 1.2, label = "-0.22") +  
  coord_flip() + 
  scale_x_discrete(limits = c("Conservative Ideology among Blacks",
                              "Conservative Ideology among Whites",
                              "Interaction Effect for Liberal-Conservative and Black"))


#---- Produce a figure like Figure 9.4b in R showing how the	effect of being Black on the propensity to approve of Obama varies with ideology ----
summary(mod1)

b1 <- mod1$coefficients[1]; b1
b2 <- mod1$coefficients[2]; b2
b3 <- mod1$coefficients[3]; b3
b4 <- mod1$coefficients[4]; b4
b5 <- mod1$coefficients[5]; b5
b6 <- mod1$coefficients[6]; b6
b7 <- summary(mod1)$coefficients[7, 1]; b7
b8 <- summary(mod1)$coefficients[8, 1]; b8
b9 <- summary(mod1)$coefficients[9, 1]; b9

varb1 <- vcov(mod1)[1, 1]; varb1
varb2 <- vcov(mod1)[2, 2]; varb2
varb3 <- vcov(mod1)[3, 3]; varb3
varb4 <- vcov(mod1)[4, 4]; varb4
varb5 <- vcov(mod1)[5, 5]; varb5
varb6 <- vcov(mod1)[6, 6]; varb6

covb1b3 <- vcov(mod1)[1, 3]; covb1b3
covb3b2 <- vcov(mod1)[3, 2]; covb3b2
covb4b5 <- vcov(mod1)[4, 5]; covb4b5

vcov(mod1)

n <- 1:71
MV <- (n-1)/10
conbx <- b2+b3*MV 
consx <- sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2)
z <- qnorm(0.975); z
lowerx <- conbx-(z*consx)
upperx <- conbx+(z*consx)

#---- Produce the plot like Figure 9.4b. ----
# The plot is not identical to the one in Figure 9.4b  because the histogram doesn't 
# distinguish between Blacks and Whites. It is possible to add	
# histograms by Blacks and Whites but the two histograms each sum	
# to 100 percent when we want them together to sum to 100 	
# percent. There's probably an easy way to get this, but we 	
# didn't use R

ggplot() +
  geom_line(aes(x = MV[MV>0.99], y = conbx[MV>0.99])) +
  geom_line(aes(x = MV[MV>0.99], y = upperx[MV>0.99]), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV[MV>0.99], y = lowerx[MV>0.99]), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$left_right, y = (..count..)/sum(..count..)*100/4), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Black instead of White",
    sec.axis = sec_axis(~.*4, name="Percentage of Observations")
  ) +
  xlab("Liberal-Conservative Ideology of Respondent") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")


#---- Information about percentage of observations in different	regions based on marginal effect plot. ----
total <- describe(data$left_right)$n; total

describe(data$left_right[data$left_right>1.1])
more <- describe(data$left_right[data$left_right>1.1])$n; more

(more/total)*100

rm(MV, conbx, consx, upperx, lowerx)

#---- Get data for histograms	to be used in Figure 9.4 ----
data <- data[order(data$left_right), ]
describe(data$black[data$black==1 & !is.na(data$left_right)])
describe(data$left_right[!is.na(data$black)])
table(data$left_right, data$black)

#---- Produce a figure like Figure 9.5 in R showing how the effect of a one unit increase in ideology on the probability of	different approval categories for Obama by race ----
summary(mod1)

set.seed(339487731)
sim <- mvrnorm(n = 1000, mu = summary(mod1)$coefficients[, 1], Sigma = vcov(mod1))

#---- Calculate the marginal of left_right on the probability of different approval categories for whites and blacks	when age is	45, female is 1, and worse off is 3. ----
h_economyworse <- 3
h_age <- 45
h_black <- 1
h_female <- 1
h_white <- 0
h_left_right <- 3

#---- Create a 8 x 3 matrix to store inputs for creating plot	----
plot2 <- matrix(NA, 8, 4)
colnames(plot2) <- c("estimate", "ci_lo", "ci_hi", "num")

#---- Baseline scenarios ----

# Whites
xb_white = sim[ , 1]*h_left_right + sim[ , 2]*h_white + sim[ , 3]*h_left_right*h_white + 
  sim[ , 4]*h_economyworse+ sim[ , 5]*h_female+sim[ , 6]*h_age

me_w = sim[ , 1]+sim[ , 3]*h_white

# Blacks

xb_black = sim[ , 1]*h_left_right + sim[ , 2]*h_black + sim[ , 3]*h_left_right*h_black +
  sim[ , 4]*h_economyworse+ sim[ , 5]*h_female+sim[ , 6]*h_age

me_b = sim[ , 1] +sim[ , 3]*h_black

#---- Marginal effect of left_right for Strong Disapproval (category 1) ----
  
# Whites

me_whites1 = (exp(sim[, 7]-xb_white)/((1+exp(sim[, 7]-xb_white))*(1+exp(sim[, 7]-xb_white))))*-me_w

describe(me_whites1)
plot2[1,1]=describe(me_whites1)$mean
plot2[1,2]=quantile(me_whites1, 0.025)
plot2[1,3]=quantile(me_whites1, 0.975)

#Blacks

me_blacks1 = (exp(sim[, 7]-xb_black)/((1+exp(sim[, 7]-xb_black))*(1+exp(sim[, 7]-xb_black))))*-me_b

describe(me_blacks1)
plot2[2,1]=describe(me_blacks1)$mean
plot2[2,2]=quantile(me_blacks1, 0.025)
plot2[2,3]=quantile(me_blacks1, 0.975)

# interaction effect  

int_effect1=me_blacks1-me_whites1
ratio1 = me_whites1/me_blacks1
describe(int_effect1)
describe(ratio1)
quantile(int_effect1, 0.025)
quantile(int_effect1, 0.975)
quantile(ratio1, 0.025)
quantile(ratio1, 0.975)

#---- Marginal effect of left_right for Disapproval (category 2)	----
  
# Whites

me_whites2 = ((exp(sim[, 7]-xb_white)/((1+exp(sim[, 7]-xb_white))*(1+exp(sim[, 7]-xb_white))))*me_w)-
  ((exp(sim[, 8]-xb_white)/((1+exp(sim[, 8]-xb_white))*(1+exp(sim[, 8]-xb_white))))*me_w)

describe(me_whites2)
plot2[3,1]=describe(me_whites2)$mean
plot2[3,2]=quantile(me_whites2, 0.025)
plot2[3,3]=quantile(me_whites2, 0.975)

# Blacks
  
me_blacks2 = ((exp(sim[, 7]-xb_black)/((1+exp(sim[, 7]-xb_black))*(1+exp(sim[, 7]-xb_black))))*me_b)- ((exp(sim[, 8]-xb_black)/((1+exp(sim[, 8]-xb_black))*(1+exp(sim[, 8]-xb_black))))*me_b)

describe(me_blacks2)
plot2[4,1]=describe(me_blacks2)$mean
plot2[4,2]=quantile(me_blacks2, 0.025)
plot2[4,3]=quantile(me_blacks2, 0.975)

# interaction effect 
  
int_effect2=me_blacks2-me_whites2
ratio2 = me_whites2/me_blacks2
describe(int_effect2)
describe(ratio2)
quantile(int_effect2, 0.025)
quantile(int_effect2, 0.975)
quantile(ratio2, 0.025)
quantile(ratio2, 0.975)

#---- Marginal effect of left_right for Approval (category 3) ----
  
# Whites

me_whites3 = ((exp(sim[, 8]-xb_white)/((1+exp(sim[, 8]-xb_white))*(1+exp(sim[, 8]-xb_white))))*me_w)-
  ((exp(sim[, 9]-xb_white)/((1+exp(sim[, 9]-xb_white))*(1+exp(sim[, 9]-xb_white))))*me_w)

describe(me_whites3)
plot2[5,1]=describe(me_whites3)$mean
plot2[5,2]=quantile(me_whites3, 0.025)
plot2[5,3]=quantile(me_whites3, 0.975)

# Blacks

me_blacks3 = ((exp(sim[, 8]-xb_black)/((1+exp(sim[, 8]-xb_black))*(1+exp(sim[, 8]-xb_black))))*me_b)- 
  ((exp(sim[, 9]-xb_black)/((1+exp(sim[, 9]-xb_black))*(1+exp(sim[, 9]-xb_black))))*me_b)

describe(me_blacks3)
plot2[6,1]=describe(me_blacks3)$mean
plot2[6,2]=quantile(me_blacks3, 0.025)
plot2[6,3]=quantile(me_blacks3, 0.975)

# interaction effect
  
int_effect3=me_blacks3-me_whites3
ratio3 = me_whites3/me_blacks3
describe(int_effect3)
describe(ratio3)
quantile(int_effect3, 0.025)
quantile(int_effect3, 0.975)
quantile(ratio3, 0.025)
quantile(ratio3, 0.975)

#----	Marginal effect of left_right for Strong Approval (category 4) ----
  
# Whites

me_whites4 = (exp(sim[, 9]-xb_white)/((1+exp(sim[, 9]-xb_white))*(1+exp(sim[, 9]-xb_white))))*me_w

describe(me_whites4)
plot2[7,1]=describe(me_whites4)$mean
plot2[7,2]=quantile(me_whites4, 0.025)
plot2[7,3]=quantile(me_whites4, 0.975)

# Blacks

me_blacks4 = (exp(sim[, 9]-xb_black)/((1+exp(sim[, 9]-xb_black))*(1+exp(sim[, 9]-xb_black))))*me_b

describe(me_blacks4)
plot2[8,1]=describe(me_blacks4)$mean
plot2[8,2]=quantile(me_blacks4, 0.025)
plot2[8,3]=quantile(me_blacks4, 0.975)

# interaction effect
  
int_effect4=me_blacks4-me_whites4
ratio4 = me_whites4/me_blacks4
describe(int_effect4)
describe(ratio4)
quantile(int_effect4, 0.025)
quantile(int_effect4, 0.975)
quantile(ratio4, 0.025)
quantile(ratio4, 0.975)

plot2
plot2[, 4] <- c(8:1)

#---- Produce Figure 9.5 using ggplot2	----
ggplot(data.frame(plot2)) + 
  geom_pointrange(aes(x = num, y = estimate, ymin = ci_lo, ymax = ci_hi)) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  ylim(-.26, .15) +
  labs(y = "Marginal Effect of Liberal-Conservative", x = "", shape = "", title = "") +
  theme_bw()  +
  annotate("text", y  = 0.119, x = 8.2, label = "0.119") +  
  annotate("text", y  = 0.005, x = 7.2, label = "0.005") +  
  annotate("text", y  = 0.080, x = 6.2, label = "0.080") +  
  annotate("text", y  = 0.006, x = 5.2, label = "0.006") +  
  annotate("text", y  = 0.039, x = 4.2, label = "0.039") +  
  annotate("text", y  = 0.024, x = 3.2, label = "0.024") +  
  annotate("text", y  = -0.237, x = 2.2, label = "-0.237") +  
  annotate("text", y  = -0.035, x = 1.2, label = "-0.035") +  
  coord_flip() + 
  scale_x_discrete(limits = c("Strong Approval: Blacks",
                              "Strong Approval: Whites",
                              "Approval: Blacks",
                              "Approval: Whites",
                              "Disapproval: Blacks",
                              "Disapproval: Whites",
                              "Strong Disapproval: Blacks",
                              "Strong Disapproval: Whites"))

  
#---- Calculate the information to go in Table 9.2 examining the effect of a one unit increase in ideology on the probability of different approval categories for Obama by race	----
  
#---- We already have our baseline scenarios. Let's get our counterfactual scenarios. ----
xb_white_c = sim[ , 1]*(h_left_right+1) + sim[ , 2]*h_white + sim[ , 3]*(h_left_right+1)*h_white + 
                    sim[ , 4]*h_economyworse+ sim[ , 5]*h_female+sim[ , 6]*h_age
            
xb_black_c = sim[ , 1]*(h_left_right+1) + sim[ , 2]*h_black + sim[ , 3]*(h_left_right+1)*h_black +
                    sim[ , 4]*h_economyworse+ sim[ , 5]*h_female+sim[ , 6]*h_age
            
#---- Effect of one unit increase in left_right for Strong  Disapproval (category 1) ----

# Whites 

prob_whites1b= (exp(sim[, 7]-xb_white))/(1+exp(sim[, 7]-xb_white))

prob_whites1c= (exp(sim[, 7]-xb_white_c))/(1+exp(sim[, 7]-xb_white_c))

diff_whites1= prob_whites1c-prob_whites1b

percent_whites1= (diff_whites1/prob_whites1b)*100

describe(prob_whites1b)
describe(prob_whites1c)
describe(diff_whites1)
describe(percent_whites1)
quantile(prob_whites1b, 0.025)
quantile(prob_whites1b, 0.975)
quantile(prob_whites1c, 0.025)
quantile(prob_whites1c, 0.975)
quantile(diff_whites1, 0.025)
quantile(diff_whites1, 0.975)
quantile(percent_whites1, 0.025)
quantile(percent_whites1, 0.975)

# Blacks 
prob_blacks1b= (exp(sim[, 7]-xb_black))/(1+exp(sim[, 7]-xb_black))

prob_blacks1c= (exp(sim[, 7]-xb_black_c))/(1+exp(sim[, 7]-xb_black_c))

diff_blacks1= prob_blacks1c-prob_blacks1b

percent_blacks1= (diff_blacks1/prob_blacks1b)*100

describe(prob_blacks1b)
describe(prob_blacks1c)
describe(diff_blacks1)
describe(percent_blacks1)
quantile(prob_blacks1b, 0.025)
quantile(prob_blacks1b, 0.975)
quantile(prob_blacks1c, 0.025)
quantile(prob_blacks1c, 0.975)
quantile(diff_blacks1, 0.025)
quantile(diff_blacks1, 0.975)
quantile(percent_blacks1, 0.025)
quantile(percent_blacks1, 0.975)

# Interaction Effect 

diffb1=prob_blacks1b-prob_whites1b
diffc1=prob_blacks1c-prob_whites1c

describe(diffb1)
describe(diffc1)
quantile(diffb1, 0.025)
quantile(diffb1, 0.975)
quantile(diffc1, 0.025)
quantile(diffc1, 0.975)

interaction_effect1 = diff_blacks1 - diff_whites1
percent_interaction_effect1 = (1-(percent_blacks1/percent_whites1))*100

describe(interaction_effect1)
describe(percent_interaction_effect1)
quantile(interaction_effect1, 0.025)
quantile(interaction_effect1, 0.975)
quantile(percent_interaction_effect1, 0.025)
quantile(percent_interaction_effect1, 0.975)

#----	Effect of one unit increase in left_right for Disapproval (category 2) ----

# Whites

prob_whites2b= ((exp(sim[, 8]-xb_white))/(1+exp(sim[, 8]-xb_white))) - 
  ((exp(sim[, 7]-xb_white))/(1+exp(sim[, 7]-xb_white)))

prob_whites2c = ((exp(sim[, 8]-xb_white_c))/(1+exp(sim[, 8]-xb_white_c))) -
  ((exp(sim[, 7]-xb_white_c))/(1+exp(sim[, 7]-xb_white_c)))

diff_whites2= prob_whites2c-prob_whites2b

percent_whites2= (diff_whites2/prob_whites2b)*100

describe(prob_whites2b)
describe(prob_whites2c)
describe(diff_whites2)
describe(percent_whites2)
quantile(prob_whites2b, 0.025)
quantile(prob_whites2b, 0.975)
quantile(prob_whites2c, 0.025)
quantile(prob_whites2c, 0.975)
quantile(diff_whites2, 0.025)
quantile(diff_whites2, 0.975)
quantile(percent_whites2, 0.025)
quantile(percent_whites2, 0.975)

# Blacks

prob_blacks2b= ((exp(sim[, 8]-xb_black))/(1+exp(sim[, 8]-xb_black))) -
  ((exp(sim[, 7]-xb_black))/(1+exp(sim[, 7]-xb_black)))

prob_blacks2c = ((exp(sim[, 8]-xb_black_c))/(1+exp(sim[, 8]-xb_black_c))) -
  ((exp(sim[, 7]-xb_black_c))/(1+exp(sim[, 7]-xb_black_c)))

diff_blacks2= prob_blacks2c-prob_blacks2b

percent_blacks2= (diff_blacks2/prob_blacks2b)*100

describe(prob_blacks2b)
describe(prob_blacks2c)
describe(diff_blacks2)
describe(percent_blacks2)
quantile(prob_blacks2b, 0.025)
quantile(prob_blacks2b, 0.975)
quantile(prob_blacks2c, 0.025)
quantile(prob_blacks2c, 0.975)
quantile(diff_blacks2, 0.025)
quantile(diff_blacks2, 0.975)
quantile(percent_blacks2, 0.025)
quantile(percent_blacks2, 0.975)

# Interaction Effect 

diffb2=prob_blacks2b-prob_whites2b
diffc2=prob_blacks2c-prob_whites2c

describe(diffb2)
describe(diffc2)
quantile(diffb2, 0.025)
quantile(diffb2, 0.975)
quantile(diffc2, 0.025)
quantile(diffc2, 0.975)

interaction_effect2 = diff_blacks2 - diff_whites2
percent_interaction_effect2 = (1-(percent_blacks2/percent_whites2))*100

describe(interaction_effect2)
describe(percent_interaction_effect2)
quantile(interaction_effect2, 0.025)
quantile(interaction_effect2, 0.975)
quantile(percent_interaction_effect2, 0.025)
quantile(percent_interaction_effect2, 0.975)

#---- Effect of one unit increase in left_right for Approval (category 3) ----

# Whites 

prob_whites3b= ((exp(sim[, 9]-xb_white))/(1+exp(sim[, 9]-xb_white))) - 
  ((exp(sim[, 8]-xb_white))/(1+exp(sim[, 8]-xb_white)))

prob_whites3c = ((exp(sim[, 9]-xb_white_c))/(1+exp(sim[, 9]-xb_white_c))) -
  ((exp(sim[, 8]-xb_white_c))/(1+exp(sim[, 8]-xb_white_c)))

diff_whites3= prob_whites3c-prob_whites3b

percent_whites3= (diff_whites3/prob_whites3b)*100

describe(prob_whites3b)
describe(prob_whites3c)
describe(diff_whites3)
describe(percent_whites3)
quantile(prob_whites3b, 0.025)
quantile(prob_whites3b, 0.975)
quantile(prob_whites3c, 0.025)
quantile(prob_whites3c, 0.975)
quantile(diff_whites3, 0.025)
quantile(diff_whites3, 0.975)
quantile(percent_whites3, 0.025)
quantile(percent_whites3, 0.975)

#---- So, marginal effect of left-right on category 3 for whites is positive but the effect of a one unit increase in left-right is negative. To check this is correct, I calculated the marginal effect again using a different formula using Lambda instead of lambda. It seems to be correct.----

t2=(exp(sim[, 8]-xb_white))/(1+exp(sim[, 8]-xb_white))

t3=(exp(sim[, 9]-xb_white))/(1+exp(sim[, 9]-xb_white))

me = ((t2*(1-t2))-(t3*(1-t3)))*sim[ , 1]

describe(me)
quantile(me, 0.025)
quantile(me, 0.975)

# Blacks 

prob_blacks3b= ((exp(sim[, 9]-xb_black))/(1+exp(sim[, 9]-xb_black))) -
  ((exp(sim[, 8]-xb_black))/(1+exp(sim[, 8]-xb_black)))

prob_blacks3c = ((exp(sim[, 9]-xb_black_c))/(1+exp(sim[, 9]-xb_black_c))) -
  ((exp(sim[, 8]-xb_black_c))/(1+exp(sim[, 8]-xb_black_c)))

diff_blacks3 = prob_blacks3c-prob_blacks3b

percent_blacks3= (diff_blacks3/prob_blacks3b)*100

describe(prob_blacks3b)
describe(prob_blacks3c)
describe(diff_blacks3)
describe(percent_blacks3)
quantile(prob_blacks3b, 0.025)
quantile(prob_blacks3b, 0.975)
quantile(prob_blacks3c, 0.025)
quantile(prob_blacks3c, 0.975)
quantile(diff_blacks3, 0.025)
quantile(diff_blacks3, 0.975)
quantile(percent_blacks3, 0.025)
quantile(percent_blacks3, 0.975) 

# Interaction Effect

diffb3=prob_blacks3b-prob_whites3b
diffc3=prob_blacks3c-prob_whites3c

describe(diffb3)
describe(diffc3)
quantile(diffb3, 0.025)
quantile(diffb3, 0.975)
quantile(diffc3, 0.025)
quantile(diffc3, 0.975)

interaction_effect3 = diff_blacks3 - diff_whites3
percent_interaction_effect3 = (1-(percent_blacks3/percent_whites3))*100

describe(interaction_effect3)
describe(percent_interaction_effect3)
quantile(interaction_effect3, 0.025)
quantile(interaction_effect3, 0.975)
quantile(percent_interaction_effect3, 0.025)
quantile(percent_interaction_effect3, 0.975)

#---- Effect of one unit increase in left_right for Strong Approval (category 4) ----

# Whites

prob_whites4b= 1-((exp(sim[, 9]-xb_white))/(1+exp(sim[, 9]-xb_white)))

prob_whites4c= 1-((exp(sim[, 9]-xb_white_c))/(1+exp(sim[, 9]-xb_white_c)))

diff_whites4= prob_whites4c-prob_whites4b

percent_whites4= (diff_whites4/prob_whites4b)*100

describe(prob_whites4b)
describe(prob_whites4c)
describe(diff_whites4)
describe(percent_whites4)
quantile(prob_whites4b, 0.025)
quantile(prob_whites4b, 0.975)
quantile(prob_whites4c, 0.025)
quantile(prob_whites4c, 0.975)
quantile(diff_whites4, 0.025)
quantile(diff_whites4, 0.975)
quantile(percent_whites4, 0.025)
quantile(percent_whites4, 0.975)

# Blacks

prob_blacks4b= 1-((exp(sim[, 9]-xb_black))/(1+exp(sim[, 9]-xb_black)))

prob_blacks4c= 1-((exp(sim[, 9]-xb_black_c))/(1+exp(sim[, 9]-xb_black_c)))

diff_blacks4= prob_blacks4c-prob_blacks4b

percent_blacks4= (diff_blacks4/prob_blacks4b)*100

describe(prob_blacks4b)
describe(prob_blacks4c)
describe(diff_blacks4)
describe(percent_blacks4)
quantile(prob_blacks4b, 0.025)
quantile(prob_blacks4b, 0.975)
quantile(prob_blacks4c, 0.025)
quantile(prob_blacks4c, 0.975)
quantile(diff_blacks4, 0.025)
quantile(diff_blacks4, 0.975)
quantile(percent_blacks4, 0.025)
quantile(percent_blacks4, 0.975)

# Interaction Effect 

diffb4=prob_blacks4b-prob_whites4b
diffc4=prob_blacks4c-prob_whites4c

describe(diffb4)
describe(diffc4)
quantile(diffb4, 0.025)
quantile(diffb4, 0.975)
quantile(diffc4, 0.025)
quantile(diffc4, 0.975)

interaction_effect4 = diff_blacks4 - diff_whites4
percent_interaction_effect4 = (1-(percent_blacks4/percent_whites4))*100

describe(interaction_effect4)
describe(percent_interaction_effect4)
quantile(interaction_effect4, 0.025)
quantile(interaction_effect4, 0.975)
quantile(percent_interaction_effect4, 0.025)
quantile(percent_interaction_effect4, 0.975)

#---- Produce a figure like Figure 9.6 in R showing how the	factor change associated with being Black in the odds of an approval category greater than some category k versus a lower approval category varies across different levels of conservative ideology	 ----
summary(mod1)
low <- exp(mod1$coefficients[2] + mod1$coefficients[3]*1); low
hi <- exp(mod1$coefficients[2] + mod1$coefficients[3]*7); hi
hi/low

odds_hat <- vector()
odds_lo <- vector()
odds_hi <- vector() 	
a <- 0
j <- 1
while(a <= 7.1){
  odds_lo[j] <- exp((mod1$coefficients[2] + mod1$coefficients[3]*a) - qnorm(0.975)*deltamethod(~ (x2 + x3*a), summary(mod1)$coefficients[, 1], vcov(mod1)))
  odds_hi[j] <- exp((mod1$coefficients[2] + mod1$coefficients[3]*a) + qnorm(0.975)*deltamethod(~ (x2 + x3*a), summary(mod1)$coefficients[, 1], vcov(mod1)))
  odds_hat[j] <- exp(mod1$coefficients[2] + mod1$coefficients[3]*a)
  a <- a + 0.1
  j <- j + 1
  
}

n <- 1:72
MV <- (n-1)/10


ggplot() +
  geom_line(aes(x = MV, y = odds_hat)) +
  geom_line(aes(x = MV, y = odds_hi), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = odds_lo), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$left_right, y = (..count..)/sum(..count..)*100*10), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Factor Change in the Odds of Y > k",
    sec.axis = sec_axis(~./10, name="Percentage of Observations")
  ) +
  xlab("Liberal-Conservative Ideology of Respondent") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

txtStop()

